using System;
using System.Diagnostics;
using System.Text;
using com.epson.bank.driver;

namespace TMS_Sample
{
	class CBarcode
	{
		private CProperty_1 m_objProperty = null;

		public CBarcode()
		{
		}

		public ErrorCode Init(CProperty_1 objProperty)
		{
			ErrorCode errResult = ErrorCode.SUCCESS;
			m_objProperty = objProperty;

			return errResult;
		}

		public ErrorCode SetBarcodeSetting()
		{
			ErrorCode errResult = ErrorCode.SUCCESS;

			// Settings for front side
			errResult = m_objProperty.GetMfDevice().SCNMICRFunctionContinuously(m_objProperty.GetMfBarcodeFront(), FunctionType.MF_GET_BARCODE_FRONT_DEFAULT);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			// Specify barcode symbols to be decoded
			m_objProperty.GetMfBarcodeFront().Info[0].SymbolMask = m_objProperty.GetBarcodeTypeMask();

			// Barcode detection error
			m_objProperty.GetMfBarcodeFront().ErrorSelect = m_objProperty.GetBarcodeDetect();
			if (m_objProperty.GetBarcodeDetect() == MfErrorSelect.MF_ERROR_SELECT_DETECT)
			{
				m_objProperty.GetMfBarcodeFront().ErrorEject = m_objProperty.GetBarcodeEject();
				m_objProperty.GetMfBarcodeFront().Cancel = m_objProperty.GetBarcodeCancel();
			}

			errResult = m_objProperty.GetMfDevice().SCNMICRFunctionContinuously(m_objProperty.GetMfBarcodeFront(), FunctionType.MF_SET_BARCODE_FRONT_PARAM);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			return errResult;
		}

		public ErrorCode GetBarcode(ref CBarcodeResult objBarcodeResult)
		{
			ErrorCode errResult = ErrorCode.SUCCESS;
			if(objBarcodeResult == null)
			{
				return ErrorCode.ERR_UNKNOWN;
			}

			errResult = m_objProperty.GetMfDevice().SCNSelectScanFace(ScanSide.MF_SCAN_FACE_FRONT);
			Debug.Assert(errResult == ErrorCode.SUCCESS);
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			errResult = m_objProperty.GetMfDevice().GetBarcodeData(m_objProperty.GetTransactionNumber(), m_objProperty.GetMfBarcodeFront());
			Debug.Assert(errResult == ErrorCode.SUCCESS || errResult == ErrorCode.ERR_BARCODE_NODATA );
			if (errResult != ErrorCode.SUCCESS)
			{
				return errResult;
			}

			if(m_objProperty.GetMfBarcodeFront().Data != null)
			{
				string strBarcodeCombined = "";
				MFBarcode.BarcodeData[] BarcodeData = m_objProperty.GetMfBarcodeFront().Data;
				int nCount = BarcodeData.Length;
				for (int nIndex = 0; nIndex < nCount; nIndex++)
				{
					// MFBarcode.BarcodeData.Data must include null terminator.
					// Chop null terminator by shrinking length.
					string strBarcode = Encoding.ASCII.GetString(BarcodeData[nIndex].Data, 0, BarcodeData[nIndex].Data.Length - 1);

					// And also, CODE-128 may include null character. Replace it to show on the screen.
					strBarcode = strBarcode.Replace('\0', ' ');

					if ( strBarcodeCombined.Length == 0 )
					{
						strBarcodeCombined = strBarcode;
					}
					else
					{
						strBarcodeCombined += " ";
						strBarcodeCombined += strBarcode;
					}
				}
				objBarcodeResult.SetBarcodeData(strBarcodeCombined);
			}
			else
			{
				objBarcodeResult.SetBarcodeData("");
			}

			return errResult;
		}
	}
}

