#include "stdafx.h"
#include "App.h"

CApp*	g_pApp;

CApp::CApp(void)
{
	// Step 1
	g_pApp					= this;
	m_pFuncProcessErrorCB	= NULL;
}

CApp::~CApp(void)
{
	ExitDevice();
	g_pApp = NULL;
}

// Initialize
int CApp::InitDevice(void)
{
	int nResult = SUCCESS;

	if(m_CCProperty.GetLibrary() == NULL)
	{
		// Load the TM-S9000/S2000 API driver
		HINSTANCE hLibrary = ::LoadLibrary(_T("EpsStmApiWrapper.dll"));
		ASSERT( hLibrary != NULL );
		if(hLibrary == NULL)
		{
			return ERR_LOAD_MODULE;
		}
		m_CCProperty.SetLibrary(hLibrary);
	}

	GetAPIProcAddress();

	if(m_CCProperty.GetHandle() <= 0)
	{
		// Connect to the device
		int nHandle = BiOpenMonPrinter(TYPE_PRINTER, "TM-S9000U,TM-S2000U");
		ASSERT( nHandle > SUCCESS );
		if(nHandle <= 0)
		{
			return nHandle;
		}

		m_CCProperty.SetHandle(nHandle);
	}

	m_CCScan.Init(&m_CCProperty);
	m_CCMicr.Init(&m_CCProperty);
	m_CCOption.Init(&m_CCProperty);

	// Step 1
	// Register callback function for notification of the reading status
	nResult = BiSCNMICRSetStatusBackFunction(m_CCProperty.GetHandle(), cbScanStatus);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Post process
int CApp::ExitDevice(void)
{
	int nResult = SUCCESS;

	if(m_CCProperty.GetHandle() > 0)
	{
		// Cancel the reading status callback
		nResult = BiSCNMICRCancelStatusBack(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		// Disconnect the device
		nResult = BiCloseMonPrinter(m_CCProperty.GetHandle());
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		m_CCProperty.SetHandle(0);
	}

	if(m_CCProperty.GetLibrary() != NULL)
	{
		// Unload the driver
		::FreeLibrary(m_CCProperty.GetLibrary());
		m_CCProperty.SetLibrary(NULL);
	}

	return nResult;
}

// Step 1
// Register callback function for notification of error during image acquisition
void CApp::SetProcessErrorCallback(PROCESS_ERROR_BACK_FUNC pProcessErrorCB)
{
	m_pFuncProcessErrorCB = pProcessErrorCB;
}

// Step 1
// Check scanning process
int CApp::ScanCheck(void)
{
	int nResult = SUCCESS;

	// Step 1
	// Set MF_BASE01 structure
	nResult = m_CCScan.SetBaseSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set check scanning conditions
	nResult = m_CCScan.SetScanSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MICR reading conditions
	nResult = m_CCMicr.SetMicrSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set MF_PROCESS01 structure
	nResult = m_CCOption.SetProcessSetting();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Start check scanning
	nResult = m_CCScan.ScanFunction();
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Error recovery
int CApp::CancelError(void)
{
	return BiCancelError(m_CCProperty.GetHandle());
}

// Get device status
int CApp::GetDeviceStatus(LPDWORD lpStatus)
{
	return BiGetStatus(m_CCProperty.GetHandle(), lpStatus);
}

// Get ink status
int CApp::GetInkStatus(LPWORD lpStatus)
{
	return BiGetInkStatus(m_CCProperty.GetHandle(), lpStatus);
}

// Cancel scanning
int CApp::CancelScan(void)
{
	return m_CCScan.CancelScan();
}

// Get functions of the API
void CApp::GetAPIProcAddress(void)
{
	HINSTANCE hLibrary = m_CCProperty.GetLibrary();

	// Step 1
	BiOpenMonPrinter				= (DLL_BiOpenMonPrinter)				GetProcAddress(hLibrary, "BiOpenMonPrinter");
	BiCloseMonPrinter				= (DLL_BiCloseMonPrinter)				GetProcAddress(hLibrary, "BiCloseMonPrinter");
	BiSCNMICRSetStatusBackFunction	= (DLL_BiSCNMICRSetStatusBackFunction)	GetProcAddress(hLibrary, "BiSCNMICRSetStatusBackFunction");
	BiSCNMICRCancelStatusBack		= (DLL_BiSCNMICRCancelStatusBack)		GetProcAddress(hLibrary, "BiSCNMICRCancelStatusBack");
	BiCancelError					= (DLL_BiCancelError)					GetProcAddress(hLibrary, "BiCancelError");
	BiGetStatus						= (DLL_BiGetStatus)						GetProcAddress(hLibrary, "BiGetStatus");
	BiGetInkStatus					= (DLL_BiGetInkStatus)					GetProcAddress(hLibrary, "BiGetInkStatus");
}

// Callback function for notifying scanning status
int CApp::cbScanStatus(DWORD dwTransactionNumber, WORD wMainStatus, WORD wSubStatus, LPSTR pPortName)
{
	return g_pApp->ScanStatus(dwTransactionNumber, wMainStatus, wSubStatus, pPortName);
}

int CApp::ScanStatus(DWORD dwTransactionNumber, WORD wMainStatus, WORD wSubStatus, LPSTR pPortName)
{
	if(wSubStatus != SUCCESS)
	{
		m_pFuncProcessErrorCB( static_cast<short>(wSubStatus) );
	}

	return 0;
}
