// TMS_SampleDlg.cpp : implementation file
//

#include "stdafx.h"
#include "TMS_Sample.h"
#include "TMS_SampleDlg.h"

#ifdef _DEBUG
#define new DEBUG_NEW
#endif

/////////////////////////////////////////////////////////////////
// Functions for Callback from DriverControl
/////////////////////////////////////////////////////////////////

////////////////
//// Step 1 ////
////////////////

int CALLBACK CallbackFuncProcessError( short sErrorStatus )
{
	CTMS_SampleDlg* pDlg = dynamic_cast<CTMS_SampleDlg*>( AfxGetApp()->GetMainWnd() );
	if( pDlg != NULL )
	{
		pDlg->CallbackProcProcessError( sErrorStatus );
	}

	return 0;
}

// CTMS_SampleDlg dialog

CTMS_SampleDlg::CTMS_SampleDlg(CWnd* pParent /*=NULL*/)
	: CDialog(CTMS_SampleDlg::IDD, pParent)
{
	m_hIcon = AfxGetApp()->LoadIcon(IDR_MAINFRAME);
	m_bScanCancelError = false;

	////////////////
	//// Step 1 ////
	////////////////

	m_pcDriverControl = new CApp;
}

CTMS_SampleDlg::~CTMS_SampleDlg(void)
{
	if( m_pcDriverControl != NULL )
	{
		delete m_pcDriverControl;
		m_pcDriverControl = NULL;
	}
}

void CTMS_SampleDlg::DoDataExchange(CDataExchange* pDX)
{
	CDialog::DoDataExchange(pDX);
	// Step 1
	DDX_Control(pDX, IDC_BUTTON_SCAN, m_btnScan);
	DDX_Control(pDX, IDC_BUTTON_SCANCANCEL, m_btnScanCancel);
	DDX_Control(pDX, IDC_BUTTON_EXIT, m_btnExit);
}

BEGIN_MESSAGE_MAP(CTMS_SampleDlg, CDialog)
	ON_WM_SYSCOMMAND()
	ON_WM_PAINT()
	ON_WM_QUERYDRAGICON()
	//}}AFX_MSG_MAP
	// Step 1
	ON_BN_CLICKED(IDC_BUTTON_SCAN, &CTMS_SampleDlg::OnBnClickedButtonScan)
	ON_BN_CLICKED(IDC_BUTTON_SCANCANCEL, &CTMS_SampleDlg::OnBnClickedButtonScanCancel)
	ON_BN_CLICKED(IDC_BUTTON_EXIT, &CTMS_SampleDlg::OnBnClickedButtonExit)
END_MESSAGE_MAP()

/////////////////////////////////////////////////////////////////
// CTMS_SampleDlg message handlers
/////////////////////////////////////////////////////////////////

BOOL CTMS_SampleDlg::OnInitDialog(void)
{
	CDialog::OnInitDialog();

	// Set the icon for this dialog.  The framework does this automatically
	//  when the application's main window is not a dialog
	SetIcon(m_hIcon, TRUE);			// Set big icon
	SetIcon(m_hIcon, FALSE);		// Set small icon

	// TODO: Add extra initialization here

	// Initialize driver
	if( InitializeDriver() != true )
	{
		EndDialog(0);
		return FALSE;
	}

	// Initialize controls
	LoadResourceString();

	return TRUE;  // return TRUE  unless you set the focus to a control
}

BOOL CTMS_SampleDlg::DestroyWindow(void)
{
	int nResult = TerminateDriver();
	if( nResult != 0 )
	{
		ShowErrorMessage( nResult );
	}

	return CDialog::DestroyWindow();
}

void CTMS_SampleDlg::OnSysCommand(UINT nID, LPARAM lParam)
{
	CDialog::OnSysCommand(nID, lParam);
}

// If you add a minimize button to your dialog, you will need the code below
//  to draw the icon.  For MFC applications using the document/view model,
//  this is automatically done for you by the framework.

void CTMS_SampleDlg::OnPaint(void)
{
	if (IsIconic())
	{
		CPaintDC dc(this); // device context for painting

		SendMessage(WM_ICONERASEBKGND, reinterpret_cast<WPARAM>(dc.GetSafeHdc()), 0);

		// Center icon in client rectangle
		int cxIcon = GetSystemMetrics(SM_CXICON);
		int cyIcon = GetSystemMetrics(SM_CYICON);
		CRect rect;
		GetClientRect(&rect);
		int x = (rect.Width() - cxIcon + 1) / 2;
		int y = (rect.Height() - cyIcon + 1) / 2;

		// Draw the icon
		dc.DrawIcon(x, y, m_hIcon);
	}
	else
	{
		CDialog::OnPaint();
	}
}

// The system calls this function to obtain the cursor to display while the user drags
//  the minimized window.
HCURSOR CTMS_SampleDlg::OnQueryDragIcon(void)
{
	return static_cast<HCURSOR>(m_hIcon);
}

/////////////////////////////////////////////////////////////////
// Procedure of DriveControl Callback
/////////////////////////////////////////////////////////////////

////////////////
//// Step 1 ////
////////////////

void CTMS_SampleDlg::CallbackProcProcessError( short sErrorStatus )
{
	// Member check
	ASSERT(m_pcDriverControl != NULL);
	if( m_pcDriverControl == NULL )
	{
		return;
	}

	DWORD  dwStatus = 0;
	// Display message box correspondent to error
	switch( sErrorStatus )
	{
		case ERR_COVER_OPEN:
			do
			{
				MessageBox( MSG_01_001, CAPTION_01_001, MB_OK | MB_ICONERROR );
				m_pcDriverControl->GetDeviceStatus(&dwStatus);
			}while( (dwStatus & ASB_COVER_OPEN) == ASB_COVER_OPEN );
			m_pcDriverControl->CancelError();
			break;

		case ERR_PAPER_JAM:
			{
				do{
					MessageBox( MSG_02_000, CAPTION_02_000, MB_OK | MB_ICONERROR );
					m_pcDriverControl->GetDeviceStatus(&dwStatus);
				}while( ((dwStatus & ASB_PAPER_INTERMEDIATE) != ASB_PAPER_INTERMEDIATE)
							|| ((dwStatus & ASB_SLIP_PAPER_SIZE) != ASB_SLIP_PAPER_SIZE)
							|| ((dwStatus & ASB_EJECT_SENSOR_NO_PAPER) != ASB_EJECT_SENSOR_NO_PAPER));
				m_pcDriverControl->CancelError();
			}
			break;

		case ERR_ACCESS:
			ShowErrorMessage( (int)sErrorStatus );
			m_pcDriverControl->CancelError();
			break;

		case ERR_MICR_NODATA:
		case ERR_MICR_BADDATA:
		case ERR_PRINT_DATA_UNRECEIVE:
			break;

		default:
			ShowErrorMessage( (int)sErrorStatus );
			m_pcDriverControl->CancelError();
			break;
	}
}

/////////////////////////////////////////////////////////////////
// Button Event
/////////////////////////////////////////////////////////////////

////////////////
//// Step 1 ////
////////////////

void CTMS_SampleDlg::OnBnClickedButtonScan(void)
{
	// Member check
	ASSERT(m_pcDriverControl != NULL);
	if( m_pcDriverControl == NULL )
	{
		return;
	}

	////////////////////////////////////////
	// Start scanning image

	{
		// Step 1
		int nRet = m_pcDriverControl->ScanCheck();
		if( nRet != SUCCESS )
		{
			ShowErrorMessage( nRet );
			m_pcDriverControl->CancelError();
			return;
		}
	}
}

void CTMS_SampleDlg::OnBnClickedButtonScanCancel(void)
{
	// Member check
	ASSERT(m_pcDriverControl != NULL);
	if( m_pcDriverControl == NULL )
	{
		return;
	}

	int nRet = m_pcDriverControl->CancelScan();
	if( nRet != SUCCESS )
	{
		m_bScanCancelError = true;
		ShowErrorMessage( nRet );
		m_pcDriverControl->CancelError();
	}
}

void CTMS_SampleDlg::OnBnClickedButtonExit(void)
{
	OnCancel();
}

/////////////////////////////////////////////////////////////////
// Member functions
/////////////////////////////////////////////////////////////////

bool CTMS_SampleDlg::InitializeDriver(void)
{
	// Member check
	ASSERT(m_pcDriverControl != NULL);
	if( m_pcDriverControl == NULL )
	{
		return false;
	}

	int nResult = 0;
	int nRet	= 0;
	CString strResult = NULL;

	// Open device and register callback functions
	nResult = m_pcDriverControl->InitDevice();
	while( nResult != SUCCESS )
	{
		if( nResult == ERR_LOAD_MODULE )
		{
			nRet = MessageBox( MSG_06_000, CAPTION_06_000, MB_OKCANCEL | MB_ICONERROR );
		}
		else
		{
			strResult = GetErrorString( nResult );
			nRet = MessageBox( MSG_00_000, strResult, MB_OKCANCEL | MB_ICONERROR );
		}

		if( nRet == IDOK )
		{
			nResult = m_pcDriverControl->InitDevice();
		}
		else
		{
			return false;
		}
	}

	// Specify callback function from DriverControl
	// Step 1
	m_pcDriverControl->SetProcessErrorCallback(&CallbackFuncProcessError);

	return true;
}

int CTMS_SampleDlg::TerminateDriver(void)
{
	// Member check
	ASSERT(m_pcDriverControl != NULL);
	if( m_pcDriverControl == NULL )
	{
		return ERR_NO_MEMORY;
	}

	int nRet = m_pcDriverControl->ExitDevice();
	if( nRet != SUCCESS )
	{
		return nRet;
	}

	return 0;
}

void CTMS_SampleDlg::ShowErrorMessage( int nResult )
{
	switch( nResult )
	{
		case ERR_TYPE:
			MessageBox( MSG_03_000, CAPTION_03_000, MB_OK | MB_ICONWARNING );
			break;
		case ERR_OPENED:
			MessageBox( MSG_03_001, CAPTION_03_001, MB_OK | MB_ICONWARNING );
			break;
		case ERR_NO_PRINTER:
			MessageBox( MSG_03_002, CAPTION_03_002, MB_OK | MB_ICONWARNING );
			break;
		case ERR_NO_TARGET:
			MessageBox( MSG_03_003, CAPTION_03_003, MB_OK | MB_ICONWARNING );
			break;
		case ERR_NO_MEMORY:
			MessageBox( MSG_03_004, CAPTION_03_004, MB_OK | MB_ICONWARNING );
			break;
		case ERR_HANDLE:
			MessageBox( MSG_03_005, CAPTION_03_005, MB_OK | MB_ICONWARNING );
			break;
		case ERR_TIMEOUT:
			MessageBox( MSG_03_006, CAPTION_03_006, MB_OK | MB_ICONWARNING );
			break;
		case ERR_ACCESS:
			MessageBox( MSG_03_007, CAPTION_03_007, MB_OK | MB_ICONWARNING );
			break;
		case ERR_PARAM:
			MessageBox( MSG_03_008, CAPTION_03_008, MB_OK | MB_ICONWARNING );
			break;
		case ERR_NOT_SUPPORT:
			MessageBox( MSG_03_009, CAPTION_03_009, MB_OK | MB_ICONWARNING );
			break;
		case ERR_OFFLINE:
			MessageBox( MSG_03_010, CAPTION_03_010, MB_OK | MB_ICONWARNING );
			break;
		case ERR_NOT_EPSON:
			MessageBox( MSG_03_011, CAPTION_03_011, MB_OK | MB_ICONWARNING );
			break;
		case ERR_WITHOUT_CB:
			if( m_bScanCancelError == true )
			{
				MessageBox( MSG_03_012_01, CAPTION_03_012, MB_OK | MB_ICONWARNING );
				m_bScanCancelError = false;
			}
			else
			{
				MessageBox( MSG_03_012_00, CAPTION_03_012, MB_OK | MB_ICONWARNING );
			}
			break;
		case ERR_BUFFER_OVER_FLOW:
			MessageBox( MSG_03_013, CAPTION_03_013, MB_OK | MB_ICONWARNING );
			break;
		case ERR_REGISTRY:
			MessageBox( MSG_03_014, CAPTION_03_014, MB_OK | MB_ICONWARNING );
			break;
		case ERR_PAPERINSERT_TIMEOUT:
			MessageBox( MSG_03_015, CAPTION_03_015, MB_OK | MB_ICONWARNING );
			break;
		case ERR_EXEC_FUNCTION:
			MessageBox( MSG_03_016, CAPTION_03_016, MB_OK | MB_ICONWARNING );
			break;
		case ERR_EXEC_MICR:
			MessageBox( MSG_03_017, CAPTION_03_017, MB_OK | MB_ICONWARNING );
			break;
		case ERR_EXEC_SCAN:
			MessageBox( MSG_03_018, CAPTION_03_018, MB_OK | MB_ICONWARNING );
			break;
		case ERR_RESET:
			MessageBox( MSG_03_019, CAPTION_03_019, MB_OK | MB_ICONWARNING );
			break;
		case ERR_ABORT:
			MessageBox( MSG_03_020, CAPTION_03_020, MB_OK | MB_ICONWARNING );
			break;
		case ERR_MICR:
			MessageBox( MSG_03_021, CAPTION_03_021, MB_OK | MB_ICONWARNING );
			break;
		case ERR_SCAN:
			MessageBox( MSG_03_022, CAPTION_03_022, MB_OK | MB_ICONWARNING );
			break;
		case ERR_LINE_OVERFLOW:
			MessageBox( MSG_03_023, CAPTION_03_023, MB_OK | MB_ICONWARNING );
			break;
		case ERR_PAPER_PILED:
			MessageBox( MSG_03_024, CAPTION_03_024, MB_OK | MB_ICONWARNING );
			break;
		case ERR_PAPER_JAM:
			MessageBox( MSG_03_025, CAPTION_03_025, MB_OK | MB_ICONWARNING );
			break;
		case ERR_COVER_OPEN:
			MessageBox( MSG_03_026, CAPTION_03_026, MB_OK | MB_ICONWARNING );
			break;
		case ERR_MICR_NODATA:
			MessageBox( MSG_03_027, CAPTION_03_027, MB_OK | MB_ICONWARNING );
			break;
		case ERR_MICR_BADDATA:
			MessageBox( MSG_03_028, CAPTION_03_028, MB_OK | MB_ICONWARNING );
			break;
		case ERR_MICR_NOISE:
			MessageBox( MSG_03_029, CAPTION_03_029, MB_OK | MB_ICONWARNING );
			break;
		case ERR_SCN_COMPRESS:
			MessageBox( MSG_03_030, CAPTION_03_030, MB_OK | MB_ICONWARNING );
			break;
		case ERR_PAPER_EXIST:
			MessageBox( MSG_03_031, CAPTION_03_031, MB_OK | MB_ICONWARNING );
			break;
		case ERR_PAPER_INSERT:
			MessageBox( MSG_03_032, CAPTION_03_032, MB_OK | MB_ICONWARNING );
			break;
		case ERR_EXEC_SCAN_CHECK_CONTINUOUS:
			MessageBox( MSG_03_033, CAPTION_03_033, MB_OK | MB_ICONWARNING );
			break;
		case ERR_EXEC_SCAN_CHECK_ONEBYONE:
			MessageBox( MSG_03_034, CAPTION_03_034, MB_OK | MB_ICONWARNING );
			break;
		case ERR_EXEC_SCAN_IDCARD:
			MessageBox( MSG_03_035, CAPTION_03_035, MB_OK | MB_ICONWARNING );
			break;
		case ERR_EXEC_PRINT_ROLLPAPER:
			MessageBox( MSG_03_036, CAPTION_03_036, MB_OK | MB_ICONWARNING );
			break;
		case ERR_EXEC_PRINT_VALIDATION:
			MessageBox( MSG_03_037, CAPTION_03_037, MB_OK | MB_ICONWARNING );
			break;
		case ERR_THREAD:
			MessageBox( MSG_03_038, CAPTION_03_038, MB_OK | MB_ICONWARNING );
			break;
		case ERR_IMAGE_FILEOPEN:
			MessageBox( MSG_03_039, CAPTION_03_039, MB_OK | MB_ICONWARNING );
			break;
		case ERR_IMAGE_UNKNOWNFORMAT:
			MessageBox( MSG_03_040, CAPTION_03_040, MB_OK | MB_ICONWARNING );
			break;
		case ERR_SIZE:
			MessageBox( MSG_03_041, CAPTION_03_041, MB_OK | MB_ICONWARNING );
			break;
		case ERR_NOT_FOUND:
			MessageBox( MSG_03_042, CAPTION_03_042, MB_OK | MB_ICONWARNING );
			break;
		case ERR_NOT_EXEC:
			MessageBox( MSG_03_043, CAPTION_03_043, MB_OK | MB_ICONWARNING );
			break;
		case ERR_BARCODE_NODATA:
			MessageBox( MSG_03_044, CAPTION_03_044, MB_OK | MB_ICONWARNING );
			break;
		case ERR_MICR_PARSE:
			MessageBox( MSG_03_045, CAPTION_03_045, MB_OK | MB_ICONWARNING );
			break;
		case ERR_SCN_IQA:
			MessageBox( MSG_03_046, CAPTION_03_046, MB_OK | MB_ICONWARNING );
			break;
		case ERR_PRINT_DATA_LENGTH_EXCEED:
			MessageBox( MSG_03_047, CAPTION_03_047, MB_OK | MB_ICONWARNING );
			break;
		case ERR_PRINT_DATA_UNRECEIVE:
			MessageBox( MSG_03_048, CAPTION_03_048, MB_OK | MB_ICONWARNING );
			break;
		case ERR_INK_STATUS:
			MessageBox( MSG_03_050, CAPTION_03_051, MB_OK | MB_ICONWARNING );
			break;
		case ERR_IMAGE_FILEREAD:
			MessageBox( MSG_03_049, CAPTION_03_049, MB_OK | MB_ICONWARNING );
			break;
		default:
			static CString strResult;
			strResult.Format( _T("%d"), nResult );
			MessageBox( strResult, _T("ERR"), MB_OK | MB_ICONWARNING );
			break;
	}
}

LPCTSTR CTMS_SampleDlg::GetErrorString( int nResultCode )
{
	switch( nResultCode )
	{
			case SUCCESS:
				return CAPTION_00_000;
			case ERR_TYPE:
				return CAPTION_03_000;
			case ERR_OPENED:
				return CAPTION_03_001;
			case ERR_NO_PRINTER:
				return CAPTION_03_002;
			case ERR_NO_TARGET:
				return CAPTION_03_003;
			case ERR_NO_MEMORY:
				return CAPTION_03_004;
			case ERR_HANDLE:
				return CAPTION_03_005;
			case ERR_TIMEOUT:
				return CAPTION_03_006;
			case ERR_ACCESS:
				return CAPTION_03_007;
			case ERR_PARAM:
				return CAPTION_03_008;
			case ERR_NOT_SUPPORT:
				return CAPTION_03_009;
			case ERR_OFFLINE:
				return CAPTION_03_010;
			case ERR_NOT_EPSON:
				return CAPTION_03_011;
			case ERR_WITHOUT_CB:
				return CAPTION_03_012;
			case ERR_BUFFER_OVER_FLOW:
				return CAPTION_03_013;
			case ERR_REGISTRY:
				return CAPTION_03_014;
			case ERR_PAPERINSERT_TIMEOUT:
				return CAPTION_03_015;
			case ERR_EXEC_FUNCTION:
				return CAPTION_03_016;
			case ERR_EXEC_MICR:
				return CAPTION_03_017;
			case ERR_EXEC_SCAN:
				return CAPTION_03_018;
			case ERR_RESET:
				return CAPTION_03_019;
			case ERR_ABORT:
				return CAPTION_03_020;
			case ERR_MICR:
				return CAPTION_03_021;
			case ERR_SCAN:
				return CAPTION_03_022;
			case ERR_LINE_OVERFLOW:
				return CAPTION_03_023;
			case ERR_PAPER_PILED:
				return CAPTION_03_024;
			case ERR_PAPER_JAM:
				return CAPTION_03_025;
			case ERR_COVER_OPEN:
				return CAPTION_03_026;
			case ERR_MICR_NODATA:
				return CAPTION_03_027;
			case ERR_MICR_BADDATA:
				return CAPTION_03_028;
			case ERR_MICR_NOISE:
				return CAPTION_03_029;
			case ERR_SCN_COMPRESS:
				return CAPTION_03_030;
			case ERR_PAPER_EXIST:
				return CAPTION_03_031;
			case ERR_PAPER_INSERT:
				return CAPTION_03_032;
			case ERR_EXEC_SCAN_CHECK_CONTINUOUS:
				return CAPTION_03_033;
			case ERR_EXEC_SCAN_CHECK_ONEBYONE:
				return CAPTION_03_034;
			case ERR_EXEC_SCAN_IDCARD:
				return CAPTION_03_035;
			case ERR_EXEC_PRINT_ROLLPAPER:
				return CAPTION_03_036;
			case ERR_EXEC_PRINT_VALIDATION:
				return CAPTION_03_037;
			case ERR_THREAD:
				return CAPTION_03_038;
			case ERR_IMAGE_FILEOPEN:
				return CAPTION_03_039;
			case ERR_IMAGE_UNKNOWNFORMAT:
				return CAPTION_03_040;
			case ERR_SIZE:
				return CAPTION_03_041;
			case ERR_NOT_FOUND:
				return CAPTION_03_042;
			case ERR_NOT_EXEC:
				return CAPTION_03_043;
			case ERR_BARCODE_NODATA:
				return CAPTION_03_044;
			case ERR_MICR_PARSE:
				return CAPTION_03_045;
			case ERR_SCN_IQA:
				return CAPTION_03_046;
			case ERR_PRINT_DATA_LENGTH_EXCEED:
				return CAPTION_03_047;
			case ERR_PRINT_DATA_UNRECEIVE:
				return CAPTION_03_048;
			case ERR_INK_STATUS:
				return CAPTION_03_051;
			case ERR_IMAGE_FILEREAD:
				return CAPTION_03_049;
			default:
				static CString strResult;
				strResult.Format( _T("%d"), nResultCode );
				return strResult;
	}
}

void CTMS_SampleDlg::LoadResourceString(void)
{
	////////////////
	//// Step 1 ////
	////////////////

	// Title
	this->SetWindowText( STR_SAMPLEDLG_TITLE );

	// Scan Button
	m_btnScan.SetWindowText( STR_SAMPLEDLG_BUTTON_SCAN );

	// ScanCancel Button
	m_btnScanCancel.SetWindowText( STR_SAMPLEDLG_BUTTON_SCANCANCEL );

	// Exit Button
	m_btnExit.SetWindowText( STR_SAMPLEDLG_BUTTON_EXIT );
}
