#include "stdafx.h"
#include "Endorse.h"
#include <shlwapi.h>

CEndorse::CEndorse(void)
{
	m_pCProperty = NULL;
	m_vLogoImage.clear();
}

CEndorse::~CEndorse(void)
{
}

int CEndorse::Init(CProperty_1* pProperty)
{
	int nResult = SUCCESS;

	m_pCProperty = pProperty;

	GetAPIProcAddress();

	return nResult;
}

int CEndorse::LoadEndorseFile(void)
{
	int nResult = SUCCESS;

	// Set print information for physical endorsement
	nResult = BiSetPrintStation(m_pCProperty->GetHandle(), MF_ST_PHYSICAL_ENDORSEMENT);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Compose path, API Driver supports only MBCS.
	char szPath[_MAX_PATH] = {0};
	(void)::GetModuleFileNameA (NULL, szPath, _countof(szPath));
	(void)::PathRemoveFileSpecA(szPath);
	(void)::PathAppendA        (szPath, "FormatSettingStep4.ini");

	// Loading printing region setting file for template printing
	int nLoadNum = 0;
	nResult = BiLoadTemplatePrintArea(m_pCProperty->GetHandle(), szPath, &nLoadNum);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// Set print information for electronic endorsement
	nResult = BiSetPrintStation(m_pCProperty->GetHandle(), MF_ST_E_ENDORSEMENT);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	nResult = BiLoadTemplatePrintArea(m_pCProperty->GetHandle(), szPath, &nLoadNum);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

int CEndorse::SetEndorseStation(void)
{
	int nResult = SUCCESS;

	// Select print station
	nResult = BiSetPrintStation(m_pCProperty->GetHandle(), m_pCProperty->GetEndorseType());
	ASSERT( nResult == SUCCESS );

	if (m_pCProperty->GetPayeeEndorse())
	{
		nResult = BiSetConfigure(
				m_pCProperty->GetHandle(),
				MF_CONFIG_ID_ENDORSE_PRINT_POSITION,
				MF_CONFIG_TYPE_ENDORSE_PRINT_POSITION_PAYEE_ENDORSE );
	}
	else
	{
		nResult = BiSetConfigure(
				m_pCProperty->GetHandle(),
				MF_CONFIG_ID_ENDORSE_PRINT_POSITION,
				MF_CONFIG_TYPE_ENDORSE_PRINT_POSITION_NORMAL );
	}

	return nResult;
}

int CEndorse::PhysicalEndorseFunction(unsigned long ulTransactionNumber)
{
	int nResult = SUCCESS;

	if ( m_pCProperty->GetEnableEndorsePrint() == false )
	{
		return SUCCESS;
	}

	// Start buffering of print data for format printing
	nResult = BiTemplatePrint(m_pCProperty->GetHandle(), TEMPLATEPRINT_BUFFERING);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// set strings for printing
	{
		MF_DECORATE tDecorate;
		tDecorate.dwAttribute = MF_PRINT_NO_ATTRIBUTE;
		tDecorate.wFont = MF_PRINT_SYSTEMFONT;
		tDecorate.szFontName = "Arial";
		tDecorate.wFontSize = 9;

		CString strEndorseString = NULL;
		CString strAddString = NULL;
		SYSTEMTIME stSystemTime;
		char *pcMonth[] = {"","Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};

		/*PhysicalEndorseText1*/
		if ( m_pCProperty->GetPayeeEndorse() )
		{
			nResult = BiSetTemplatePrintArea(m_pCProperty->GetHandle(), SELECTPRINTAREA_AREANAME, "PhysicalEndorseText1_CW", NULL, ulTransactionNumber);
		}
		else
		{
			nResult = BiSetTemplatePrintArea(m_pCProperty->GetHandle(), SELECTPRINTAREA_AREANAME, "PhysicalEndorseText1", NULL, ulTransactionNumber);
		}
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		GetSystemTime(&stSystemTime);

		strAddString.Format( _T("  %s %02d %04d\n"), pcMonth[stSystemTime.wMonth], stSystemTime.wDay,stSystemTime.wYear );
		strEndorseString += strAddString;

		strAddString.Format( _T("  %02d:%02d:%02d:%d\n\n"),
			stSystemTime.wHour, stSystemTime.wMinute, stSystemTime.wSecond, stSystemTime.wMilliseconds );
		strEndorseString += strAddString;
		
		strAddString.Format( _T("  &>1234567890&<") );
		strEndorseString += strAddString;

		nResult = BiSCNPrintText(m_pCProperty->GetHandle(), ulTransactionNumber, CStrBufA(strEndorseString), &tDecorate);
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		/*PhysicalEndorseText2*/
		if ( m_pCProperty->GetPayeeEndorse() )
		{
			nResult = BiSetTemplatePrintArea(m_pCProperty->GetHandle(), SELECTPRINTAREA_AREANAME, "PhysicalEndorseText2_CW", NULL, ulTransactionNumber);
		}
		else
		{
			nResult = BiSetTemplatePrintArea(m_pCProperty->GetHandle(), SELECTPRINTAREA_AREANAME, "PhysicalEndorseText2", NULL, ulTransactionNumber);
		}
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		strEndorseString = _T("  &>1234567890&<");
		nResult = BiSCNPrintText(m_pCProperty->GetHandle(), ulTransactionNumber, CStrBufA(strEndorseString), &tDecorate);
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}
	}

	// Print buffered data
	nResult = BiTemplatePrint(m_pCProperty->GetHandle(), TEMPLATEPRINT_EXEC);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

int CEndorse::ElectronicEndorseFunction(unsigned long ulTransactionNumber)
{
	int nResult = SUCCESS;

	// Start buffering of print data for format printing
	nResult = BiTemplatePrint(m_pCProperty->GetHandle(), TEMPLATEPRINT_BUFFERING);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	// set strings for printing
	{
		MF_DECORATE tDecorate;
		tDecorate.dwAttribute = MF_PRINT_NO_ATTRIBUTE;
		tDecorate.wFont = MF_PRINT_SYSTEMFONT;
		tDecorate.szFontName = "Arial";
		tDecorate.wFontSize = 9;

		CString strEndorseString = NULL;
		CString strAddString = NULL;
		SYSTEMTIME stSystemTime;
		char *pcMonth[] = {"","Jan","Feb","Mar","Apr","May","Jun","Jul","Aug","Sep","Oct","Nov","Dec"};

		/*EndorseText1*/
		nResult = BiSetTemplatePrintArea(m_pCProperty->GetHandle(), SELECTPRINTAREA_AREANAME, "ElectronicEndorseText1", NULL, TRANS_NO_SPECIFIED);
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		GetSystemTime(&stSystemTime);

		strAddString.Format( _T("  %s %02d %04d\n"), pcMonth[stSystemTime.wMonth], stSystemTime.wDay,stSystemTime.wYear );
		strEndorseString += strAddString;

		strAddString.Format( _T("  %02d:%02d:%02d:%d\n\n"),
			stSystemTime.wHour, stSystemTime.wMinute, stSystemTime.wSecond, stSystemTime.wMilliseconds );
		strEndorseString += strAddString;
		
		strAddString.Format( _T("  &>1234567890&<") );
		strEndorseString += strAddString;

		nResult = BiPrintText(m_pCProperty->GetHandle(), CStrBufA(strEndorseString), tDecorate);
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		/*EndorseText2*/
		nResult = BiSetTemplatePrintArea(m_pCProperty->GetHandle(), SELECTPRINTAREA_AREANAME, "ElectronicEndorseText2", NULL, TRANS_NO_SPECIFIED);
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}

		strEndorseString = _T("  &>1234567890&<");
		nResult = BiPrintText(m_pCProperty->GetHandle(), CStrBufA(strEndorseString), tDecorate);
		ASSERT( nResult == SUCCESS );
		if(nResult != SUCCESS)
		{
			return nResult;
		}
	}

	// Print buffered data
	nResult = BiTemplatePrint(m_pCProperty->GetHandle(), TEMPLATEPRINT_EXEC);
	ASSERT( nResult == SUCCESS );
	if(nResult != SUCCESS)
	{
		return nResult;
	}

	return nResult;
}

// Get functions of the API
void CEndorse::GetAPIProcAddress(void)
{
	HINSTANCE hLibrary = m_pCProperty->GetLibrary();

	BiSetPrintStation			= (DLL_BiSetPrintStation)		GetProcAddress(hLibrary, "BiSetPrintStation");
	BiSetConfigure				= (DLL_BiSetConfigure)			GetProcAddress(hLibrary, "BiSetConfigure");
	BiPrintText					= (DLL_BiPrintText)				GetProcAddress(hLibrary, "BiPrintText");
	BiPrintImage				= (DLL_BiPrintImage)			GetProcAddress(hLibrary, "BiPrintImage");
	BiSCNPrintText				= (DLL_BiSCNPrintText)			GetProcAddress(hLibrary, "BiSCNPrintText");
	BiSCNPrintMemoryImage		= (DLL_BiSCNPrintMemoryImage)	GetProcAddress(hLibrary, "BiSCNPrintMemoryImage");
	BiLoadTemplatePrintArea		= (DLL_BiLoadTemplatePrintArea)	GetProcAddress(hLibrary, "BiLoadTemplatePrintArea");
	BiTemplatePrint				= (DLL_BiTemplatePrint)			GetProcAddress(hLibrary, "BiTemplatePrint");
	BiSetTemplatePrintArea		= (DLL_BiSetTemplatePrintArea)	GetProcAddress(hLibrary, "BiSetTemplatePrintArea");
}
