Imports System.Diagnostics
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Windows.Forms
Imports System.IO
Imports com.epson.bank.driver

Namespace TMS_Sample
	Public Partial Class TMS_SampleForm
		Inherits Form
		Private m_objDriverControl As CApp = Nothing
		Private m_objConfigData As StructByStep = Nothing

		Private Delegate Function ShowMessageType(text As String, caption As String, buttons As MessageBoxButtons, icon As MessageBoxIcon) As DialogResult
		Private Delegate Sub ShowErrorMessageType(errResult As ErrorCode)

		' Deligates to invoke
		Private ShowMessage As ShowMessageType = Nothing
		Private ShowErrorMessage As ShowErrorMessageType = Nothing

		' Step 1
		Private m_bScanCancelError As Boolean = False

		Public Sub New()
			InitializeComponent()
		End Sub

		Protected Overrides Sub Dispose(disposing As Boolean)
			If disposing Then
				If components IsNot Nothing Then
					components.Dispose()
				End If
				' end process
				Dim errRet As ErrorCode = ErrorCode.SUCCESS

				Try
					If m_objDriverControl IsNot Nothing Then
						errRet = TerminateDriver()
						If errRet <> ErrorCode.SUCCESS Then
							ShowErrorMessage(errRet)
						End If
					End If
				Catch
					MyBase.Dispose(disposing)
				End Try
			End If
			MyBase.Dispose(disposing)
		End Sub

		' Windows 64-bit has problem with FormLoad and unhandled exception, be carefull.
		' http://social.msdn.microsoft.com/Forums/vstudio/en-US/69a0b831-7782-4bd9-b910-25c85f18bceb/visual-studio-doesnt-break-on-unhandled-exception-with-windows-64bit?forum=vsdebug
		Private Sub TMS_SampleForm_Load(sender As Object, e As EventArgs)
			' Create driver and data instance
			Try
				' Setting up deligates to invoke
				ShowMessage = New ShowMessageType(AddressOf ShowMessageImpl)
				ShowErrorMessage = New ShowErrorMessageType(AddressOf ShowErrorMessageImpl)

				' Create driver and data instance
				m_objDriverControl = New CApp()
				m_objConfigData = New StructByStep()

				If InitializeDriver() <> True Then
					Me.Close()
					Return
				End If

				' Initialize controls
				LoadResourceString()
			Catch ex As Exception
				ShowMessage(ex.Message, ConstComStr.CAPTION_06_000, MessageBoxButtons.OK, MessageBoxIcon.[Error])
				Me.Close()
				Return
			End Try
		End Sub

		'''//////////////////////////////////////////////////////////////
		' Procedure of DriveControl Callback
		'''//////////////////////////////////////////////////////////////

		'''/////////////
		'''/ Step 1 ////
		'''/////////////

		Private Sub CallbackProcProcessError(errResult As ErrorCode)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			Dim eStatus As New ASB()
			' Display message box correspondent to error
			Select Case errResult
				Case ErrorCode.ERR_COVER_OPEN
					Do
						ShowMessage(ConstComStr.MSG_01_001, ConstComStr.CAPTION_01_001, MessageBoxButtons.OK, MessageBoxIcon.[Error])
						m_objDriverControl.GetDeviceStatus(eStatus)
					Loop While (eStatus And ASB.ASB_COVER_OPEN) = ASB.ASB_COVER_OPEN
					m_objDriverControl.CancelError()
					Exit Select

				Case ErrorCode.ERR_PAPER_JAM
					If m_objConfigData.nRadio_ScanningMedia = ConstComVal.VAL_CONFIGDLG_RADIO_SM_CHECKPAPER Then
						Do
							ShowMessage(ConstComStr.MSG_02_000, ConstComStr.CAPTION_02_000, MessageBoxButtons.OK, MessageBoxIcon.[Error])
							m_objDriverControl.GetDeviceStatus(eStatus)
						Loop While ((eStatus And ASB.ASB_EJECT_SENSOR_NO_PAPER) <> ASB.ASB_EJECT_SENSOR_NO_PAPER) OrElse ((eStatus And ASB.ASB_SLIP_PAPER_SIZE) <> ASB.ASB_SLIP_PAPER_SIZE) OrElse ((eStatus And ASB.ASB_PAPER_INTERMEDIATE) <> ASB.ASB_PAPER_INTERMEDIATE)
						m_objDriverControl.CancelError()
					Else
						ShowMessage(ConstComStr.MSG_02_000, ConstComStr.CAPTION_02_000, MessageBoxButtons.OK, MessageBoxIcon.[Error])
						m_objDriverControl.CancelError()
					End If
					Exit Select

				Case ErrorCode.ERR_ACCESS
					ShowErrorMessage(errResult)
					m_objDriverControl.CancelError()
					Exit Select

				Case ErrorCode.ERR_MICR_BADDATA, ErrorCode.ERR_MICR_NODATA, ErrorCode.ERR_PRINT_DATA_UNRECEIVE
					Exit Select
				Case Else

					ShowErrorMessage(errResult)
					m_objDriverControl.CancelError()
					Exit Select
			End Select
		End Sub

		'''//////////////////////////////////////////////////////////////
		' CTMS_SampleDlg message handlers
		'''//////////////////////////////////////////////////////////////

		'''//////////////////////////////////////////////////////////////
		' Button Event
		'''//////////////////////////////////////////////////////////////

		'''/////////////
		'''/ Step 1 ////
		'''/////////////

		Private Sub btnScan_Click(sender As Object, e As EventArgs)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			'''/////////////////////////////////////
			' Start scanning image

			If True Then
				' Step 1
				Dim errRet As ErrorCode = m_objDriverControl.ScanCheck()
				If errRet <> ErrorCode.SUCCESS Then
					ShowErrorMessage(errRet)
					m_objDriverControl.CancelError()
					Return
				End If
			End If
		End Sub

		Private Sub btnExit_Click(sender As Object, e As EventArgs)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Close()
				Return
			End If

			Dim errRet As ErrorCode = m_objDriverControl.ExitDevice()
			If errRet <> ErrorCode.SUCCESS Then
				ShowErrorMessage(errRet)
			End If
			Close()
		End Sub

		Private Sub btnScanCancel_Click(sender As Object, e As EventArgs)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			Dim errRet As ErrorCode = m_objDriverControl.CancelScan()
			If errRet <> ErrorCode.SUCCESS Then
				m_bScanCancelError = True
				ShowErrorMessage(errRet)
				m_objDriverControl.CancelError()
			End If
		End Sub

		'''//////////////////////////////////////////////////////////////
		' Member functions
		'''//////////////////////////////////////////////////////////////

		Private Function InitializeDriver() As Boolean
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return False
			End If

			Dim errResult As ErrorCode = ErrorCode.SUCCESS
			Dim drRet As DialogResult = 0
			Dim strResult As String = Nothing

			' Open device and register callback functions
			errResult = m_objDriverControl.InitDevice()
			While errResult <> ErrorCode.SUCCESS
				If errResult = ErrorCode.ERR_UNKNOWN Then
					drRet = ShowMessage(ConstComStr.MSG_06_000, ConstComStr.CAPTION_06_000, MessageBoxButtons.OKCancel, MessageBoxIcon.[Error])
				Else
					strResult = GetErrorString(errResult)
					drRet = ShowMessage(ConstComStr.MSG_00_000, strResult, MessageBoxButtons.OKCancel, MessageBoxIcon.[Error])
				End If

				If drRet = DialogResult.OK Then
					errResult = m_objDriverControl.InitDevice()
				Else
					Return False
				End If
			End While

			' Specify callback function from DriverControl
			' Step 1
			m_objDriverControl.SetProcessErrorCallback(New CApp.CallbackProcProcessError(AddressOf CallbackProcProcessError))

			Return True
		End Function

		Private Function TerminateDriver() As ErrorCode
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return ErrorCode.ERR_NO_MEMORY
			End If

			Dim errRet As ErrorCode = m_objDriverControl.ExitDevice()
			If errRet <> ErrorCode.SUCCESS Then
				Return errRet
			End If

			Return errRet
		End Function

		Private Function ShowMessageImpl(text As String, caption As String, buttons As MessageBoxButtons, icon As MessageBoxIcon) As DialogResult
			If Me.InvokeRequired Then
				Return CType(Me.Invoke(ShowMessage, New Object() {text, caption, buttons, icon}), DialogResult)
			End If
			Return MessageBox.Show(text, caption, buttons, icon)
		End Function

		Private Sub ShowErrorMessageImpl(errResult As ErrorCode)
			If Me.InvokeRequired Then
				Me.Invoke(ShowErrorMessage, New Object() {errResult})
				Return
			End If

			Select Case errResult
				Case ErrorCode.ERR_TYPE
					MessageBox.Show(ConstComStr.MSG_03_000, ConstComStr.CAPTION_03_000, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_OPENED
					MessageBox.Show(ConstComStr.MSG_03_001, ConstComStr.CAPTION_03_001, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NO_PRINTER
					MessageBox.Show(ConstComStr.MSG_03_002, ConstComStr.CAPTION_03_002, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NO_TARGET
					MessageBox.Show(ConstComStr.MSG_03_003, ConstComStr.CAPTION_03_003, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NO_MEMORY
					MessageBox.Show(ConstComStr.MSG_03_004, ConstComStr.CAPTION_03_004, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_HANDLE
					MessageBox.Show(ConstComStr.MSG_03_005, ConstComStr.CAPTION_03_005, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_TIMEOUT
					MessageBox.Show(ConstComStr.MSG_03_006, ConstComStr.CAPTION_03_006, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_ACCESS
					MessageBox.Show(ConstComStr.MSG_03_007, ConstComStr.CAPTION_03_007, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PARAM
					MessageBox.Show(ConstComStr.MSG_03_008, ConstComStr.CAPTION_03_008, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NOT_SUPPORT
					MessageBox.Show(ConstComStr.MSG_03_009, ConstComStr.CAPTION_03_009, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_OFFLINE
					MessageBox.Show(ConstComStr.MSG_03_010, ConstComStr.CAPTION_03_010, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NOT_EPSON
					MessageBox.Show(ConstComStr.MSG_03_011, ConstComStr.CAPTION_03_011, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_WITHOUT_CB
					If m_bScanCancelError = True Then
						MessageBox.Show(ConstComStr.MSG_03_012_01, ConstComStr.CAPTION_03_012, MessageBoxButtons.OK, MessageBoxIcon.Warning)
						m_bScanCancelError = False
					Else
						MessageBox.Show(ConstComStr.MSG_03_012_00, ConstComStr.CAPTION_03_012, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					End If
					Exit Select
				Case ErrorCode.ERR_BUFFER_OVER_FLOW
					MessageBox.Show(ConstComStr.MSG_03_013, ConstComStr.CAPTION_03_013, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_REGISTRY
					MessageBox.Show(ConstComStr.MSG_03_014, ConstComStr.CAPTION_03_014, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPERINSERT_TIMEOUT
					MessageBox.Show(ConstComStr.MSG_03_015, ConstComStr.CAPTION_03_015, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_FUNCTION
					MessageBox.Show(ConstComStr.MSG_03_016, ConstComStr.CAPTION_03_016, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_MICR
					MessageBox.Show(ConstComStr.MSG_03_017, ConstComStr.CAPTION_03_017, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_SCAN
					MessageBox.Show(ConstComStr.MSG_03_018, ConstComStr.CAPTION_03_018, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_RESET
					MessageBox.Show(ConstComStr.MSG_03_019, ConstComStr.CAPTION_03_019, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_ABORT
					MessageBox.Show(ConstComStr.MSG_03_020, ConstComStr.CAPTION_03_020, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR
					MessageBox.Show(ConstComStr.MSG_03_021, ConstComStr.CAPTION_03_021, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_SCAN
					MessageBox.Show(ConstComStr.MSG_03_022, ConstComStr.CAPTION_03_022, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_LINE_OVERFLOW
					MessageBox.Show(ConstComStr.MSG_03_023, ConstComStr.CAPTION_03_023, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPER_PILED
					MessageBox.Show(ConstComStr.MSG_03_024, ConstComStr.CAPTION_03_024, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPER_JAM
					MessageBox.Show(ConstComStr.MSG_03_025, ConstComStr.CAPTION_03_025, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_COVER_OPEN
					MessageBox.Show(ConstComStr.MSG_03_026, ConstComStr.CAPTION_03_026, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR_NODATA
					MessageBox.Show(ConstComStr.MSG_03_027, ConstComStr.CAPTION_03_027, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR_BADDATA
					MessageBox.Show(ConstComStr.MSG_03_028, ConstComStr.CAPTION_03_028, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR_NOISE
					MessageBox.Show(ConstComStr.MSG_03_029, ConstComStr.CAPTION_03_029, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_SCN_COMPRESS
					MessageBox.Show(ConstComStr.MSG_03_030, ConstComStr.CAPTION_03_030, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPER_EXIST
					MessageBox.Show(ConstComStr.MSG_03_031, ConstComStr.CAPTION_03_031, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPER_INSERT
					MessageBox.Show(ConstComStr.MSG_03_032, ConstComStr.CAPTION_03_032, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_SCAN_CHECK_CONTINUOUS
					MessageBox.Show(ConstComStr.MSG_03_033, ConstComStr.CAPTION_03_033, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_SCAN_CHECK_ONEBYONE
					MessageBox.Show(ConstComStr.MSG_03_034, ConstComStr.CAPTION_03_034, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_SCAN_IDCARD
					MessageBox.Show(ConstComStr.MSG_03_035, ConstComStr.CAPTION_03_035, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_PRINT_ROLLPAPER
					MessageBox.Show(ConstComStr.MSG_03_036, ConstComStr.CAPTION_03_036, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_PRINT_VALIDATION
					MessageBox.Show(ConstComStr.MSG_03_037, ConstComStr.CAPTION_03_037, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_THREAD
					MessageBox.Show(ConstComStr.MSG_03_038, ConstComStr.CAPTION_03_038, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_IMAGE_FILEOPEN
					MessageBox.Show(ConstComStr.MSG_03_039, ConstComStr.CAPTION_03_039, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_IMAGE_UNKNOWNFORMAT
					MessageBox.Show(ConstComStr.MSG_03_040, ConstComStr.CAPTION_03_040, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_SIZE
					MessageBox.Show(ConstComStr.MSG_03_041, ConstComStr.CAPTION_03_041, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NOT_FOUND
					MessageBox.Show(ConstComStr.MSG_03_042, ConstComStr.CAPTION_03_042, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NOT_EXEC
					MessageBox.Show(ConstComStr.MSG_03_043, ConstComStr.CAPTION_03_043, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_BARCODE_NODATA
					MessageBox.Show(ConstComStr.MSG_03_044, ConstComStr.CAPTION_03_044, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR_PARSE
					MessageBox.Show(ConstComStr.MSG_03_045, ConstComStr.CAPTION_03_045, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_SCN_IQA
					MessageBox.Show(ConstComStr.MSG_03_046, ConstComStr.CAPTION_03_046, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PRINT_DATA_LENGTH_EXCEED
					MessageBox.Show(ConstComStr.MSG_03_047, ConstComStr.CAPTION_03_047, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PRINT_DATA_UNRECEIVE
					MessageBox.Show(ConstComStr.MSG_03_048, ConstComStr.CAPTION_03_048, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_INK_STATUS
					MessageBox.Show(ConstComStr.MSG_03_050, ConstComStr.CAPTION_03_051, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_IMAGE_FILEREAD
					MessageBox.Show(ConstComStr.MSG_03_049, ConstComStr.CAPTION_03_049, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case Else
					MessageBox.Show(errResult.ToString(), "ERR", MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
			End Select
		End Sub

		Private Function GetErrorString(errResultCode As ErrorCode) As String
			Select Case errResultCode
				Case ErrorCode.SUCCESS
					Return ConstComStr.CAPTION_00_000
				Case ErrorCode.ERR_TYPE
					Return ConstComStr.CAPTION_03_000
				Case ErrorCode.ERR_OPENED
					Return ConstComStr.CAPTION_03_001
				Case ErrorCode.ERR_NO_PRINTER
					Return ConstComStr.CAPTION_03_002
				Case ErrorCode.ERR_NO_TARGET
					Return ConstComStr.CAPTION_03_003
				Case ErrorCode.ERR_NO_MEMORY
					Return ConstComStr.CAPTION_03_004
				Case ErrorCode.ERR_HANDLE
					Return ConstComStr.CAPTION_03_005
				Case ErrorCode.ERR_TIMEOUT
					Return ConstComStr.CAPTION_03_006
				Case ErrorCode.ERR_ACCESS
					Return ConstComStr.CAPTION_03_007
				Case ErrorCode.ERR_PARAM
					Return ConstComStr.CAPTION_03_008
				Case ErrorCode.ERR_NOT_SUPPORT
					Return ConstComStr.CAPTION_03_009
				Case ErrorCode.ERR_OFFLINE
					Return ConstComStr.CAPTION_03_010
				Case ErrorCode.ERR_NOT_EPSON
					Return ConstComStr.CAPTION_03_011
				Case ErrorCode.ERR_WITHOUT_CB
					Return ConstComStr.CAPTION_03_012
				Case ErrorCode.ERR_BUFFER_OVER_FLOW
					Return ConstComStr.CAPTION_03_013
				Case ErrorCode.ERR_REGISTRY
					Return ConstComStr.CAPTION_03_014
				Case ErrorCode.ERR_PAPERINSERT_TIMEOUT
					Return ConstComStr.CAPTION_03_015
				Case ErrorCode.ERR_EXEC_FUNCTION
					Return ConstComStr.CAPTION_03_016
				Case ErrorCode.ERR_EXEC_MICR
					Return ConstComStr.CAPTION_03_017
				Case ErrorCode.ERR_EXEC_SCAN
					Return ConstComStr.CAPTION_03_018
				Case ErrorCode.ERR_RESET
					Return ConstComStr.CAPTION_03_019
				Case ErrorCode.ERR_ABORT
					Return ConstComStr.CAPTION_03_020
				Case ErrorCode.ERR_MICR
					Return ConstComStr.CAPTION_03_021
				Case ErrorCode.ERR_SCAN
					Return ConstComStr.CAPTION_03_022
				Case ErrorCode.ERR_LINE_OVERFLOW
					Return ConstComStr.CAPTION_03_023
				Case ErrorCode.ERR_PAPER_PILED
					Return ConstComStr.CAPTION_03_024
				Case ErrorCode.ERR_PAPER_JAM
					Return ConstComStr.CAPTION_03_025
				Case ErrorCode.ERR_COVER_OPEN
					Return ConstComStr.CAPTION_03_026
				Case ErrorCode.ERR_MICR_NODATA
					Return ConstComStr.CAPTION_03_027
				Case ErrorCode.ERR_MICR_BADDATA
					Return ConstComStr.CAPTION_03_028
				Case ErrorCode.ERR_MICR_NOISE
					Return ConstComStr.CAPTION_03_029
				Case ErrorCode.ERR_SCN_COMPRESS
					Return ConstComStr.CAPTION_03_030
				Case ErrorCode.ERR_PAPER_EXIST
					Return ConstComStr.CAPTION_03_031
				Case ErrorCode.ERR_PAPER_INSERT
					Return ConstComStr.CAPTION_03_032
				Case ErrorCode.ERR_EXEC_SCAN_CHECK_CONTINUOUS
					Return ConstComStr.CAPTION_03_033
				Case ErrorCode.ERR_EXEC_SCAN_CHECK_ONEBYONE
					Return ConstComStr.CAPTION_03_034
				Case ErrorCode.ERR_EXEC_SCAN_IDCARD
					Return ConstComStr.CAPTION_03_035
				Case ErrorCode.ERR_EXEC_PRINT_ROLLPAPER
					Return ConstComStr.CAPTION_03_036
				Case ErrorCode.ERR_EXEC_PRINT_VALIDATION
					Return ConstComStr.CAPTION_03_037
				Case ErrorCode.ERR_THREAD
					Return ConstComStr.CAPTION_03_038
				Case ErrorCode.ERR_IMAGE_FILEOPEN
					Return ConstComStr.CAPTION_03_039
				Case ErrorCode.ERR_IMAGE_UNKNOWNFORMAT
					Return ConstComStr.CAPTION_03_040
				Case ErrorCode.ERR_SIZE
					Return ConstComStr.CAPTION_03_041
				Case ErrorCode.ERR_NOT_FOUND
					Return ConstComStr.CAPTION_03_042
				Case ErrorCode.ERR_NOT_EXEC
					Return ConstComStr.CAPTION_03_043
				Case ErrorCode.ERR_BARCODE_NODATA
					Return ConstComStr.CAPTION_03_044
				Case ErrorCode.ERR_MICR_PARSE
					Return ConstComStr.CAPTION_03_045
				Case ErrorCode.ERR_SCN_IQA
					Return ConstComStr.CAPTION_03_046
				Case ErrorCode.ERR_PRINT_DATA_LENGTH_EXCEED
					Return ConstComStr.CAPTION_03_047
				Case ErrorCode.ERR_PRINT_DATA_UNRECEIVE
					Return ConstComStr.CAPTION_03_048
				Case ErrorCode.ERR_INK_STATUS
					Return ConstComStr.CAPTION_03_051
				Case ErrorCode.ERR_IMAGE_FILEREAD
					Return ConstComStr.CAPTION_03_049
				Case Else
					Return errResultCode.ToString()
			End Select
		End Function

		Private Sub LoadResourceString()
			'''/////////////
			'''/ Step 1 ////
			'''/////////////

			' Title
			Me.Text = ConstComStr.STR_SAMPLEDLG_TITLE

			' Scan Button
			btnScan.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_SCAN

			' ScanCancel Button
			btnScanCancel.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_SCANCANCEL

			' Exit Button
			btnExit.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_EXIT
		End Sub
	End Class
End Namespace
