Imports System.Diagnostics
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Windows.Forms
Imports com.epson.bank.driver

Namespace TMS_Sample
	Public Partial Class IqaResultForm
		Inherits Form
		' Deligates types
		Public Delegate Sub DisplayIqaResultType(objIqaResult As CIqaResult)

		' Deligates to invoke
		Public DisplayIqaResult As DisplayIqaResultType = Nothing

		Public Sub New()
			InitializeComponent()
		End Sub

		Private Sub IqaResultForm_Load(sender As Object, e As EventArgs)
			LoadResourceString()

			' Setting up deligates to invoke
			DisplayIqaResult = New DisplayIqaResultType(AddressOf DisplayIqaResultImpl)
		End Sub

		Private Sub IqaResultForm_FormClosing(sender As Object, e As FormClosingEventArgs)
			If e.CloseReason = CloseReason.UserClosing Then
				Hide()
				e.Cancel = True
			End If
		End Sub

		Public Sub LoadResourceString()
			btnClose.Text = ConstComStr.STR_IQARESULTDLG_BUTTON_CLOSE

			stIQUnderSize.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_UNDERSIZE
			stIQOverSize.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_OVERSIZE
			stIQMinCompressed.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_MINCOMPRESSED
			stIQMaxCompressed.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_MAXCOMPRESSED
			stIQFrontRearMismatch.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_FRONTREARMISMATCH
			stIQTooLight.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_TOOLIGHT
			stIQTooDark.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_TOODARK
			stIQHorizontalStreaks.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_HORIZONTALSTREAKS
			stIQSpotNoise.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_SPOTNOISE
			stIQOutOfFocus.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_OUTOFFOCUS
			stIQDocCorners.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_DOCCORNERS
			stIQDocEdges.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_DOCEDGES
			stIQFramingError.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_FRAMINGERROR
			stIQSkew.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_SKEW
			stIQCarbonStrip.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_CARBONSTRIP
			stIQPiggyback.Text = ConstComStr.STR_IQARESULTDLG_STATIC_IQ_PIGGYBACK
		End Sub

		Public Sub DisplayIqaResultImpl(objIqaResult As CIqaResult)
			If Me.InvokeRequired Then
				Me.BeginInvoke(DisplayIqaResult, New Object() {objIqaResult})
				Return
			End If

			Debug.Assert(objIqaResult IsNot Nothing)
			If objIqaResult Is Nothing Then
				Return
			End If

			SetIqaResult(objIqaResult.GetUnderSize(), edtIQUnderSize)
			SetIqaResult(objIqaResult.GetOverSize(), edtIQOverSize)
			SetIqaResult(objIqaResult.GetMinCompressed(), edtIQMinCompressed)
			SetIqaResult(objIqaResult.GetMaxCompressed(), edtIQMaxCompressed)
			SetIqaResult(objIqaResult.GetFrontRearImageMismatch(), edtIQFrontRearMismatch)
			SetIqaResult(objIqaResult.GetImageTooLight(), edtIQTooLight)
			SetIqaResult(objIqaResult.GetImageTooDark(), edtIQTooDark)
			SetIqaResult(objIqaResult.GetHorizontalStreaksPresent(), edtIQHorizontalStreaks)
			SetIqaResult(objIqaResult.GetSpotNosise(), edtIQSpotNoise)
			SetIqaResult(objIqaResult.GetOutOfFocus(), edtIQOutOfFocus)
			SetIqaResult(objIqaResult.GetFoldedTornCorner(), edtIQDocCorners)
			SetIqaResult(objIqaResult.GetFoldedTornEdge(), edtIQDocEdges)
			SetIqaResult(objIqaResult.GetFramingError(), edtIQFramingError)
			SetIqaResult(objIqaResult.GetExcessiveSkew(), edtIQSkew)
			SetIqaResult(objIqaResult.GetCarbonStripDetection(), edtIQCarbonStrip)
			SetIqaResult(objIqaResult.GetPiggyback(), edtIQPiggyback)
		End Sub

		Private Sub SetIqaResult(eIqaResult As MfIqaResultValue, ByRef edtControl As TextBox)
			If edtControl Is Nothing Then
				Debug.Assert(False)
				Return
			End If

			Select Case eIqaResult
				Case MfIqaResultValue.IQARESULT_NOT_TESTED
					edtControl.Text = "Not Tested."
					Exit Select
				Case MfIqaResultValue.IQARESULT_PASS
					edtControl.Text = "Pass."
					Exit Select
				Case MfIqaResultValue.IQARESULT_NOT_PASS
					edtControl.Text = "Not Pass."
					Exit Select
				Case Else
					Exit Select
			End Select
		End Sub

		Public Sub UpdateControls(cIqaParam As CIqaParam)
			If cIqaParam.GetUnderSize() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQUnderSize.Enabled = True
				edtIQUnderSize.Enabled = True
			Else
				stIQUnderSize.Enabled = False
				edtIQUnderSize.Enabled = False
			End If

			If cIqaParam.GetOverSize() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQOverSize.Enabled = True
				edtIQOverSize.Enabled = True
			Else
				stIQOverSize.Enabled = False
				edtIQOverSize.Enabled = False
			End If

			If cIqaParam.GetMinCompressed() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQMinCompressed.Enabled = True
				edtIQMinCompressed.Enabled = True
			Else
				stIQMinCompressed.Enabled = False
				edtIQMinCompressed.Enabled = False
			End If

			If cIqaParam.GetMaxCompressed() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQMaxCompressed.Enabled = True
				edtIQMaxCompressed.Enabled = True
			Else
				stIQMaxCompressed.Enabled = False
				edtIQMaxCompressed.Enabled = False
			End If

			If cIqaParam.GetFrontRearImageMismatch() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQFrontRearMismatch.Enabled = True
				edtIQFrontRearMismatch.Enabled = True
			Else
				stIQFrontRearMismatch.Enabled = False
				edtIQFrontRearMismatch.Enabled = False
			End If

			If cIqaParam.GetImageTooLight() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQTooLight.Enabled = True
				edtIQTooLight.Enabled = True
			Else
				stIQTooLight.Enabled = False
				edtIQTooLight.Enabled = False
			End If

			If cIqaParam.GetImageTooDark() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQTooDark.Enabled = True
				edtIQTooDark.Enabled = True
			Else
				stIQTooDark.Enabled = False
				edtIQTooDark.Enabled = False
			End If

			If cIqaParam.GetHorizontalStreaksPresent() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQHorizontalStreaks.Enabled = True
				edtIQHorizontalStreaks.Enabled = True
			Else
				stIQHorizontalStreaks.Enabled = False
				edtIQHorizontalStreaks.Enabled = False
			End If

			If cIqaParam.GetSpotNoise() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQSpotNoise.Enabled = True
				edtIQSpotNoise.Enabled = True
			Else
				stIQSpotNoise.Enabled = False
				edtIQSpotNoise.Enabled = False
			End If

			If cIqaParam.GetOutOfFocus() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQOutOfFocus.Enabled = True
				edtIQOutOfFocus.Enabled = True
			Else
				stIQOutOfFocus.Enabled = False
				edtIQOutOfFocus.Enabled = False
			End If

			If cIqaParam.GetFoldedTornCorner() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQDocCorners.Enabled = True
				edtIQDocCorners.Enabled = True
			Else
				stIQDocCorners.Enabled = False
				edtIQDocCorners.Enabled = False
			End If

			If cIqaParam.GetFoldedTornEdge() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQDocEdges.Enabled = True
				edtIQDocEdges.Enabled = True
			Else
				stIQDocEdges.Enabled = False
				edtIQDocEdges.Enabled = False
			End If

			If cIqaParam.GetFramingError() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQFramingError.Enabled = True
				edtIQFramingError.Enabled = True
			Else
				stIQFramingError.Enabled = False
				edtIQFramingError.Enabled = False
			End If

			If cIqaParam.GetExcessiveSkew() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQSkew.Enabled = True
				edtIQSkew.Enabled = True
			Else
				stIQSkew.Enabled = False
				edtIQSkew.Enabled = False
			End If

			If cIqaParam.GetCarbonStripDetection() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQCarbonStrip.Enabled = True
				edtIQCarbonStrip.Enabled = True
			Else
				stIQCarbonStrip.Enabled = False
				edtIQCarbonStrip.Enabled = False
			End If

			If cIqaParam.GetPiggyback() = MfIqaTest.MF_IQA_TEST_ENABLE Then
				stIQPiggyback.Enabled = True
				edtIQPiggyback.Enabled = True
			Else
				stIQPiggyback.Enabled = False
				edtIQPiggyback.Enabled = False
			End If
		End Sub

		Private Sub btnClose_Click(sender As Object, e As EventArgs)
			Hide()
		End Sub
	End Class
End Namespace
