Imports System.Diagnostics
Imports System.Text
Imports com.epson.bank.driver

Namespace TMS_Sample
	Class CInfo
		Public Const INFO_DEVICE_NAME As Integer = 67
		Public Const INFO_MANUFACTURE As Integer = 66
		Public Const INFO_FIRM_VERSION As Integer = 65
		Public Const INFO_SERIAL_NUMBER As Integer = 68
		Public Const INFO_SPEED_POCKET As Integer = 112

		Public Const MAX_DEVICE_INFO_SIZE As Integer = 80

		Public Const COUNTER_HEAD_ENERGIZATION As Integer = 21
		' S9000 only
		Public Const COUNTER_HEAD_LINE_FEEDS As Integer = 22
		' S9000 only
		Public Const COUNTER_LINE_FEEDS As Integer = 30
		' S9000 only
		Public Const COUNTER_HEAD_SHOT_A As Integer = 31
		Public Const COUNTER_HEAD_SHOT_B As Integer = 32
		Public Const COUNTER_PUMP_OPERATION As Integer = 34
		Public Const COUNTER_AUTO_CUTTER As Integer = 50
		' S9000 only
		Public Const COUNTER_ASF_SENDING_OFF As Integer = 67
		Public Const COUNTER_SCANNED_CHECK As Integer = 61
		Public Const COUNTER_SCANNED_CARD As Integer = 62
		Public Const COUNTER_MICR_READS As Integer = 60
		Public Const COUNTER_POCKET_SELECT As Integer = 82
		Public Const COUNTER_HOPPER As Integer = 80
		Public Const COUNTER_DEVICE_OPERATION_TIME As Integer = 70

		Private m_objProperty As CProperty_1 = Nothing

		Public Sub New()
		End Sub

		Public Function Init(objProperty As CProperty_1) As ErrorCode
			Dim errResult As ErrorCode = ErrorCode.SUCCESS
			m_objProperty = objProperty

			Return errResult
		End Function

		Public Function GetDeviceStatusFunction(ByRef objDeviceStatus As CDeviceStatus) As ErrorCode
			If objDeviceStatus Is Nothing Then
				Return ErrorCode.ERR_UNKNOWN
			End If

			Dim eStatus As ASB = m_objProperty.GetMfDevice().Status

			' ASB_NO_RESPONSE
			If (eStatus And ASB.ASB_NO_RESPONSE) = ASB.ASB_NO_RESPONSE Then
				objDeviceStatus.SetNoResponse(True)
			Else
				objDeviceStatus.SetNoResponse(False)
			End If

			' ASB_OFF_LINE
			If (eStatus And ASB.ASB_OFF_LINE) = ASB.ASB_OFF_LINE Then
				objDeviceStatus.SetOffLine(True)
			Else
				objDeviceStatus.SetOffLine(False)
			End If

			' ASB_COVER_OPEN
			If (eStatus And ASB.ASB_COVER_OPEN) = ASB.ASB_COVER_OPEN Then
				objDeviceStatus.SetCoverOpen(True)
			Else
				objDeviceStatus.SetCoverOpen(False)
			End If

			' ASB_WAIT_PEPRT_EJECT
			If (eStatus And ASB.ASB_WAIT_PEPRT_EJECT) = ASB.ASB_WAIT_PEPRT_EJECT Then
				objDeviceStatus.SetWaitPaperEject(True)
			Else
				objDeviceStatus.SetWaitPaperEject(False)
			End If

			' ASB_MECHANICAL_ERR
			If (eStatus And ASB.ASB_MECHANICAL_ERR) = ASB.ASB_MECHANICAL_ERR Then
				objDeviceStatus.SetMechanicalError(True)
			Else
				objDeviceStatus.SetMechanicalError(False)
			End If

			' ASB_UNRECOVER_ERR
			If (eStatus And ASB.ASB_UNRECOVER_ERR) = ASB.ASB_UNRECOVER_ERR Then
				objDeviceStatus.SetUnrecoverError(True)
			Else
				objDeviceStatus.SetUnrecoverError(False)
			End If

			' ASB_PAPER_INTERMEDIATE
			If (eStatus And ASB.ASB_PAPER_INTERMEDIATE) = ASB.ASB_PAPER_INTERMEDIATE Then
				objDeviceStatus.SetPaperInsermadiate(True)
			Else
				objDeviceStatus.SetPaperInsermadiate(False)
			End If

			' ASB_RECEIPT_NEAR_END
			If (eStatus And ASB.ASB_RECEIPT_NEAR_END) = ASB.ASB_RECEIPT_NEAR_END Then
				' S9000 only
				objDeviceStatus.SetReceiptNearEnd(True)
			Else
				objDeviceStatus.SetReceiptNearEnd(False)
			End If

			' ASB_EJECT_SENSOR_NO_PAPER
			If (eStatus And ASB.ASB_EJECT_SENSOR_NO_PAPER) = ASB.ASB_EJECT_SENSOR_NO_PAPER Then
				objDeviceStatus.SetEjectSensorPaper(True)
			Else
				objDeviceStatus.SetEjectSensorPaper(False)
			End If

			' ASB_RECEIPT_END
			If (eStatus And ASB.ASB_RECEIPT_END) = ASB.ASB_RECEIPT_END Then
				' S9000 only
				objDeviceStatus.SetReceiptEnd(True)
			Else
				objDeviceStatus.SetReceiptEnd(False)
			End If

			' ASB_SLIP_PAPER_SIZE
			If (eStatus And ASB.ASB_SLIP_PAPER_SIZE) = ASB.ASB_SLIP_PAPER_SIZE Then
				objDeviceStatus.SetSlipPaperSize(True)
			Else
				objDeviceStatus.SetSlipPaperSize(False)
			End If

			' ASB_ASF_PAPER
			If (eStatus And ASB.ASB_ASF_PAPER) = ASB.ASB_ASF_PAPER Then
				objDeviceStatus.SetAsfPaper(True)
			Else
				objDeviceStatus.SetAsfPaper(False)
			End If

			' ASB_WAIT_INSERT
			If (eStatus And ASB.ASB_WAIT_INSERT) = ASB.ASB_WAIT_INSERT Then
				objDeviceStatus.SetWaitInsert(True)
			Else
				objDeviceStatus.SetWaitInsert(False)
			End If

			' ASB_MAIN_POCKET_NEAR_FULL
			If (eStatus And ASB.ASB_MAIN_POCKET_NEAR_FULL) = ASB.ASB_MAIN_POCKET_NEAR_FULL Then
				objDeviceStatus.SetMainPocketNearFull(True)
			Else
				objDeviceStatus.SetMainPocketNearFull(False)
			End If

			' ASB_SUB_POCKET_NEAR_FULL
			If (eStatus And ASB.ASB_SUB_POCKET_NEAR_FULL) = ASB.ASB_SUB_POCKET_NEAR_FULL Then
				objDeviceStatus.SetSubPocketNearFull(True)
			Else
				objDeviceStatus.SetSubPocketNearFull(False)
			End If

			Return ErrorCode.SUCCESS
		End Function

		Public Function GetInkStatusFunction(ByRef objInkStatus As CInkStatus) As ErrorCode
			If objInkStatus Is Nothing Then
				Return ErrorCode.ERR_UNKNOWN
			End If

			Dim eInkASB As InkASB = m_objProperty.GetMfDevice().InkStatus

			If (eInkASB And InkASB.INK_ASB_NEAR_END) = InkASB.INK_ASB_NEAR_END Then
				objInkStatus.SetInkNearEnd(True)
			Else
				objInkStatus.SetInkNearEnd(False)
			End If

			If (eInkASB And InkASB.INK_ASB_END) = InkASB.INK_ASB_END Then
				objInkStatus.SetInkEnd(True)
			Else
				objInkStatus.SetInkEnd(False)
			End If

			If (eInkASB And InkASB.INK_ASB_NO_CARTRIDGE) = InkASB.INK_ASB_NO_CARTRIDGE Then
				objInkStatus.SetInkNoCartridge(True)
			Else
				objInkStatus.SetInkNoCartridge(False)
			End If

			If (eInkASB And InkASB.INK_ASB_CLEANING) = InkASB.INK_ASB_CLEANING Then
				objInkStatus.SetInkCleaning(True)
			Else
				objInkStatus.SetInkCleaning(False)
			End If

			Return ErrorCode.SUCCESS
		End Function

		Public Function GetDeviceInfoFunction(ByRef objDeviceInfo As CDeviceInfo) As ErrorCode
			If objDeviceInfo Is Nothing Then
				Return ErrorCode.ERR_UNKNOWN
			End If

			Dim errResult As ErrorCode = ErrorCode.SUCCESS

			' Get device name
			Dim sDeviceInfo As String
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_DEVICE_NAME, sDeviceInfo)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objDeviceInfo.SetDeviceName(sDeviceInfo)
			End If

			' Get manufacturer
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_MANUFACTURE, sDeviceInfo)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objDeviceInfo.SetManufacture(sDeviceInfo)
			End If

			' Get firmware version
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_FIRM_VERSION, sDeviceInfo)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objDeviceInfo.SetFirmVersion(sDeviceInfo)
			End If

			' Get serial number
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_SERIAL_NUMBER, sDeviceInfo)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objDeviceInfo.SetSerialNumber(sDeviceInfo)
			End If

			' Get number of pockets and document processing speed
			errResult = m_objProperty.GetMfDevice().GetPrnCapability(INFO_SPEED_POCKET, sDeviceInfo)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objDeviceInfo.SetTypeIdB(Encoding.ASCII.GetBytes(sDeviceInfo))
			End If
			Return ErrorCode.SUCCESS
		End Function

		Public Function GetMaintenanceCounterFunction(ByRef objMaintenanceCounter As CMaintenanceCounter) As ErrorCode
			If objMaintenanceCounter Is Nothing Then
				Return ErrorCode.ERR_UNKNOWN
			End If

			Dim errResult As ErrorCode = ErrorCode.SUCCESS
			Dim nCounter As Integer = 0

			' Lines fed (Roll paper)
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_LINE_FEEDS, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS OrElse errResult = ErrorCode.ERR_PARAM)
			If errResult = ErrorCode.SUCCESS Then
				' S9000
				objMaintenanceCounter.SetLineFeeds(nCounter)
			ElseIf errResult = ErrorCode.ERR_PARAM Then
				' S2000
				objMaintenanceCounter.SetLineFeeds(-1)
			Else
				Return errResult
			End If

			' Lines fed (Thermal head)
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HEAD_LINE_FEEDS, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS OrElse errResult = ErrorCode.ERR_PARAM)
			If errResult = ErrorCode.SUCCESS Then
				' S9000
				objMaintenanceCounter.SetHeadLineFeeds(nCounter)
			ElseIf errResult = ErrorCode.ERR_PARAM Then
				' S2000
				objMaintenanceCounter.SetHeadLineFeeds(-1)
			Else
				Return errResult
			End If

			' Head shot A
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HEAD_SHOT_A, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetHeadShotA(nCounter)
			Else
				Return errResult
			End If

			' Head shot B
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HEAD_SHOT_B, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetHeadShotB(nCounter)
			Else
				Return errResult
			End If

			' Thermal head energization
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HEAD_ENERGIZATION, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS OrElse errResult = ErrorCode.ERR_PARAM)
			If errResult = ErrorCode.SUCCESS Then
				' S9000
				objMaintenanceCounter.SetHeadEnergization(nCounter)
			ElseIf errResult = ErrorCode.ERR_PARAM Then
				' S2000
				objMaintenanceCounter.SetHeadEnergization(-1)
			Else
				Return errResult
			End If

			' Pump operations
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_PUMP_OPERATION, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetPumpOperation(nCounter)
			Else
				Return errResult
			End If

			' Auto cutter drive
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_AUTO_CUTTER, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS OrElse errResult = ErrorCode.ERR_PARAM)
			If errResult = ErrorCode.SUCCESS Then
				' S9000
				objMaintenanceCounter.SetAutoCutter(nCounter)
			ElseIf errResult = ErrorCode.ERR_PARAM Then
				' S2000
				objMaintenanceCounter.SetAutoCutter(-1)
			Else
				Return errResult
			End If

			' Check paper fed
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_ASF_SENDING_OFF, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetAsfSendingOff(nCounter)
			Else
				Return errResult
			End If

			' Check paper scanned
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_SCANNED_CHECK, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetImageScannedCheckPaper(nCounter)
			Else
				Return errResult
			End If

			' Card scanned
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_SCANNED_CARD, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetImageScannedCard(nCounter)
			Else
				Return errResult
			End If

			' MICR reads
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_MICR_READS, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetMicrReads(nCounter)
			Else
				Return errResult
			End If

			' Pocket switch
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_POCKET_SELECT, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetPocketSelect(nCounter)
			Else
				Return errResult
			End If

			' Hopper open/close
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_HOPPER, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetHopper(nCounter)
			Else
				Return errResult
			End If

			' Duration of product operation
			errResult = m_objProperty.GetMfDevice().GetCounter(COUNTER_DEVICE_OPERATION_TIME, nCounter)
			Debug.Assert(errResult = ErrorCode.SUCCESS)
			If errResult = ErrorCode.SUCCESS Then
				objMaintenanceCounter.SetDeviceOperationTime(nCounter)
			Else
				Return errResult
			End If

			Return errResult
		End Function
	End Class
End Namespace
