Imports System.Diagnostics
Imports System.Collections.Generic
Imports System.ComponentModel
Imports System.Data
Imports System.Drawing
Imports System.Linq
Imports System.Text
Imports System.Windows.Forms
Imports System.IO
Imports com.epson.bank.driver

Namespace TMS_Sample
	Public Partial Class TMS_SampleForm
		Inherits Form
		Private m_objDriverControl As CApp = Nothing
		Private m_objConfigData As StructByStep = Nothing

		Private Delegate Function ShowMessageType(text As String, caption As String, buttons As MessageBoxButtons, icon As MessageBoxIcon) As DialogResult
		Private Delegate Sub ShowErrorMessageType(errResult As ErrorCode)
		' Step 2
		Private Delegate Sub DisplayImageDataType()
		' Step 3
		Private Delegate Sub DisplayMicrTextType(errResult As ErrorCode, objMicrResult As CMicrResult)
		' Step 8
		Private Delegate Sub DisplayBarcodeTextType(errResult As ErrorCode, objMicrResult As CBarcodeResult)

		' Deligates to invoke
		Private ShowMessage As ShowMessageType = Nothing
		Private ShowErrorMessage As ShowErrorMessageType = Nothing
		' Step 2
		Private DisplayImageData As DisplayImageDataType = Nothing
		' Step 3
		Private DisplayMicrText As DisplayMicrTextType = Nothing
		' Step 8
		Private DisplayBarcodeText As DisplayBarcodeTextType = Nothing

		' Step 1
		Private m_bScanCancelError As Boolean = False

		' Step 2
		Private m_Image2Front As Bitmap = Nothing
		Private m_Image2Back As Bitmap = Nothing
		Private m_Image4RGBFront As Bitmap = Nothing
		Private m_Image4RGBBack As Bitmap = Nothing
		Private m_Image4IrFront As Bitmap = Nothing
		Private m_Image4IrBack As Bitmap = Nothing

		' Step 8
		Private m_objDeviceStatus As CDeviceStatus
		Private m_objInkStatus As CInkStatus
		Private m_DeviceStatusDlg As DeviceStatusForm
		Private m_DeviceInfoDlg As DeviceInfoForm

		Public Sub New()
			InitializeComponent()
		End Sub

		Protected Overrides Sub Dispose(disposing As Boolean)
			If disposing Then
				If components IsNot Nothing Then
					components.Dispose()
				End If
				' end process
				Dim errRet As ErrorCode = ErrorCode.SUCCESS

				Try
					If m_objDriverControl IsNot Nothing Then
						errRet = TerminateDriver()
						If errRet <> ErrorCode.SUCCESS Then
							ShowErrorMessage(errRet)
						End If
					End If
				Catch
					MyBase.Dispose(disposing)
				End Try
			End If
			MyBase.Dispose(disposing)
		End Sub

		' Windows 64-bit has problem with FormLoad and unhandled exception, be carefull.
		' http://social.msdn.microsoft.com/Forums/vstudio/en-US/69a0b831-7782-4bd9-b910-25c85f18bceb/visual-studio-doesnt-break-on-unhandled-exception-with-windows-64bit?forum=vsdebug
		Private Sub TMS_SampleForm_Load(sender As Object, e As EventArgs)
			' Create driver and data instance
			Try
				' Setting up deligates to invoke
				ShowMessage = New ShowMessageType(AddressOf ShowMessageImpl)
				ShowErrorMessage = New ShowErrorMessageType(AddressOf ShowErrorMessageImpl)
				' Step 2
				DisplayImageData = New DisplayImageDataType(AddressOf DisplayImageDataImpl)
				' Step 3
				DisplayMicrText = New DisplayMicrTextType(AddressOf DisplayMicrTextImpl)
				' Step 8
				DisplayBarcodeText = New DisplayBarcodeTextType(AddressOf DisplayBarcodeTextImpl)

				' Create driver and data instance
				m_objDriverControl = New CApp()
				m_objConfigData = New StructByStep()

				' Step 8
				m_objDeviceStatus = New CDeviceStatus()
				m_objInkStatus = New CInkStatus()

				If InitializeDriver() <> True Then
					Me.Close()
					Return
				End If

				' Initialize data
				InitializeConfigData()

				' Initialize controls
				LoadResourceString()

				' Create device status and device information dialogs
				m_DeviceStatusDlg = New DeviceStatusForm()
				m_DeviceStatusDlg.Owner = Me
				m_DeviceStatusDlg.Show()
				' Force to call FormLoad.
				m_DeviceStatusDlg.Hide()
				' Force to call FormLoad.
				m_DeviceStatusDlg.DisplayDeviceStatus(m_objDeviceStatus)
				m_DeviceStatusDlg.DisplayInkStatus(m_objInkStatus)

				m_DeviceInfoDlg = New DeviceInfoForm()
				m_DeviceInfoDlg.Owner = Me
				m_DeviceInfoDlg.Show()
				' Force to call FormLoad.
				m_DeviceInfoDlg.Hide()
				' Force to call FormLoad.
				UpdateControls()
			Catch ex As Exception
				ShowMessage(ex.Message, ConstComStr.CAPTION_06_000, MessageBoxButtons.OK, MessageBoxIcon.[Error])
				Me.Close()
				Return
			End Try
		End Sub

		'''//////////////////////////////////////////////////////////////
		' Procedure of DriveControl Callback
		'''//////////////////////////////////////////////////////////////

		'''/////////////
		'''/ Step 1 ////
		'''/////////////

		Private Sub CallbackProcProcessError(errResult As ErrorCode)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			Dim eStatus As New ASB()
			' Display message box correspondent to error
			Select Case errResult
				Case ErrorCode.ERR_COVER_OPEN
					Do
						ShowMessage(ConstComStr.MSG_01_001, ConstComStr.CAPTION_01_001, MessageBoxButtons.OK, MessageBoxIcon.[Error])
						m_objDriverControl.GetDeviceStatus(eStatus)
					Loop While (eStatus And ASB.ASB_COVER_OPEN) = ASB.ASB_COVER_OPEN
					m_objDriverControl.CancelError()
					Exit Select

				Case ErrorCode.ERR_PAPER_JAM
					If m_objConfigData.nRadio_ScanningMedia = ConstComVal.VAL_CONFIGDLG_RADIO_SM_CHECKPAPER Then
						Do
							ShowMessage(ConstComStr.MSG_02_000, ConstComStr.CAPTION_02_000, MessageBoxButtons.OK, MessageBoxIcon.[Error])
							m_objDriverControl.GetDeviceStatus(eStatus)
						Loop While ((eStatus And ASB.ASB_EJECT_SENSOR_NO_PAPER) <> ASB.ASB_EJECT_SENSOR_NO_PAPER) OrElse ((eStatus And ASB.ASB_SLIP_PAPER_SIZE) <> ASB.ASB_SLIP_PAPER_SIZE) OrElse ((eStatus And ASB.ASB_PAPER_INTERMEDIATE) <> ASB.ASB_PAPER_INTERMEDIATE)
						m_objDriverControl.CancelError()
					Else
						ShowMessage(ConstComStr.MSG_02_000, ConstComStr.CAPTION_02_000, MessageBoxButtons.OK, MessageBoxIcon.[Error])
						m_objDriverControl.CancelError()
					End If
					Exit Select

				Case ErrorCode.ERR_ACCESS
					ShowErrorMessage(errResult)
					m_objDriverControl.CancelError()
					Exit Select

				Case ErrorCode.ERR_MICR_BADDATA, ErrorCode.ERR_MICR_NODATA, ErrorCode.ERR_PRINT_DATA_UNRECEIVE
					Exit Select
				Case Else

					ShowErrorMessage(errResult)
					m_objDriverControl.CancelError()
					Exit Select
			End Select
		End Sub

		'''/////////////
		'''/ Step 2 ////
		'''/////////////

		Private Sub DisplayImageDataImpl()
			If Me.InvokeRequired Then
				Me.BeginInvoke(DisplayImageData, New Object() {})
				Return
			End If
			DrawImage(stImage2Front, m_Image2Front)
			DrawImage(stImage2Back, m_Image2Back)
			DrawImage(stImage4RGBFront, m_Image4RGBFront)
			DrawImage(stImage4RGBBack, m_Image4RGBBack)
			DrawImage(stImage4IRFront, m_Image4IrFront)
			DrawImage(stImage4IRBack, m_Image4IrBack)
			Me.Refresh()
		End Sub

		Private Sub CallbackProcImage()
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			' Save image if necessary
			Dim bSave As Boolean = (m_objConfigData.bCheck_Scan_SaveFile = ConstComVal.VAL_CONFIGDLG_CHECK_SC_SAVEFILE_ON)

			Dim objScanParam As New CScanParam()
			m_objDriverControl.GetScanParam(objScanParam)

			' Configure display data for each scanning side and light source
			If m_objConfigData.nRadio_LightSourceToScan = ConstComVal.VAL_CONFIGDLG_RADIO_IC_RGB Then
				' Configure 2 plane data for RGB image
				UpdateImageData(ScanSide.MF_SCAN_FACE_FRONT, ImageType.MF_SCAN_IMAGE_VISIBLE, objScanParam.GetResolution(), objScanParam.GetRGBColorDepth(), m_Image2Front, bSave)
				UpdateImageData(ScanSide.MF_SCAN_FACE_BACK, ImageType.MF_SCAN_IMAGE_VISIBLE, objScanParam.GetResolution(), objScanParam.GetRGBColorDepth(), m_Image2Back, bSave)
			ElseIf m_objConfigData.nRadio_LightSourceToScan = ConstComVal.VAL_CONFIGDLG_RADIO_IC_IR Then
				' Configure 2 plane data for IR image
				UpdateImageData(ScanSide.MF_SCAN_FACE_FRONT, ImageType.MF_SCAN_IMAGE_INFRARED, objScanParam.GetResolution(), objScanParam.GetIRColorDepth(), m_Image2Front, bSave)
				UpdateImageData(ScanSide.MF_SCAN_FACE_BACK, ImageType.MF_SCAN_IMAGE_INFRARED, objScanParam.GetResolution(), objScanParam.GetIRColorDepth(), m_Image2Back, bSave)
			ElseIf m_objConfigData.nRadio_LightSourceToScan = ConstComVal.VAL_CONFIGDLG_RADIO_IC_RGBIR Then
				' Configure 4 plane image
				UpdateImageData(ScanSide.MF_SCAN_FACE_FRONT, ImageType.MF_SCAN_IMAGE_VISIBLE, objScanParam.GetResolution(), objScanParam.GetRGBColorDepth(), m_Image4RGBFront, bSave)
				UpdateImageData(ScanSide.MF_SCAN_FACE_BACK, ImageType.MF_SCAN_IMAGE_VISIBLE, objScanParam.GetResolution(), objScanParam.GetRGBColorDepth(), m_Image4RGBBack, bSave)
				UpdateImageData(ScanSide.MF_SCAN_FACE_FRONT, ImageType.MF_SCAN_IMAGE_INFRARED, objScanParam.GetResolution(), objScanParam.GetIRColorDepth(), m_Image4IrFront, bSave)
				UpdateImageData(ScanSide.MF_SCAN_FACE_BACK, ImageType.MF_SCAN_IMAGE_INFRARED, objScanParam.GetResolution(), objScanParam.GetIRColorDepth(), m_Image4IrBack, bSave)
			Else
				Debug.Assert(False)
			End If

			DisplayImageData()
		End Sub

		'''/////////////
		'''/ Step 3 ////
		'''/////////////

		Private Sub CallbackProcMicr()
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			' Obtain MICR data
			Dim cMicrResult As New CMicrResult()
			Dim errResult As ErrorCode = m_objDriverControl.GetMicr(cMicrResult)
			DisplayMicrText(errResult, cMicrResult)
			' Deligate to DisplayMicrTextImpl
			' Save MICR data if necessary
			If m_objConfigData.bCheck_MICR_SaveFile = ConstComVal.VAL_CONFIGDLG_CHECK_MI_SAVEFILE_ON Then
				SaveMicrText(errResult, cMicrResult)
			End If
		End Sub

		Private Sub DisplayMicrTextImpl(errResult As ErrorCode, cMicrResult As CMicrResult)
			If Me.InvokeRequired Then
				Me.BeginInvoke(DisplayMicrText, New Object() {errResult, cMicrResult})
				Return
			End If

			If errResult = ErrorCode.SUCCESS Then
				edtMicrText.Text = cMicrResult.GetMicrStr()
			Else
				edtMicrText.Text = GetErrorString(errResult)
			End If
		End Sub

		'''/////////////
		'''/ Step 8 ////
		'''/////////////

		Private Sub CallbackProcBarcode()
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			Dim cBarcodeResult As New CBarcodeResult()
			Dim errResult As ErrorCode = m_objDriverControl.GetBarcode(cBarcodeResult)
			DisplayBarcodeText(errResult, cBarcodeResult)
			' Deligate to DisplayBarcodeTextImpl
		End Sub

		Private Sub DisplayBarcodeTextImpl(errResult As ErrorCode, cBarcodeResult As CBarcodeResult)
			If Me.InvokeRequired Then
				Me.BeginInvoke(DisplayBarcodeText, New Object() {errResult, cBarcodeResult})
				Return
			End If

			If errResult = ErrorCode.SUCCESS Then
				edtBarcodeData.Text = cBarcodeResult.GetBarcodeData()
			Else
				edtBarcodeData.Text = GetErrorString(errResult)
			End If
		End Sub

		Private Sub CallbackProcDeviceStatus()
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			' Get device status
			Dim errRet As ErrorCode = m_objDriverControl.GetDeviceStatusFunction(m_objDeviceStatus)
			If errRet = ErrorCode.SUCCESS Then
				m_DeviceStatusDlg.DisplayDeviceStatus(m_objDeviceStatus)
			End If
		End Sub

		Private Sub CallbackProcInkStatus()
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			' Get ink status
			Dim errRet As ErrorCode = m_objDriverControl.GetInkStatusFunction(m_objInkStatus)
			If errRet = ErrorCode.SUCCESS Then
				m_DeviceStatusDlg.DisplayInkStatus(m_objInkStatus)
			End If
		End Sub

		'''//////////////////////////////////////////////////////////////
		' CTMS_SampleDlg message handlers
		'''//////////////////////////////////////////////////////////////

		'''//////////////////////////////////////////////////////////////
		' Button Event
		'''//////////////////////////////////////////////////////////////

		'''/////////////
		'''/ Step 1 ////
		'''/////////////

		Private Sub btnScan_Click(sender As Object, e As EventArgs)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			'''/////////////////////////////////////
			' Reset controls before to start scaning

			' Step 2
			ClearImage()

			' Step 3
			edtMicrText.Text = ""

			' Step 8
			edtBarcodeData.Text = ""

			'''/////////////////////////////////////
			' Start scanning image

			' Step 2
			If m_objConfigData.nRadio_ScanningMedia = ConstComVal.VAL_CONFIGDLG_RADIO_SM_CHECKPAPER Then
				' Step 1
				Dim errRet As ErrorCode = m_objDriverControl.ScanCheck()
				If errRet <> ErrorCode.SUCCESS Then
					ShowErrorMessage(errRet)
					m_objDriverControl.CancelError()
					Return
				End If
			ElseIf m_objConfigData.nRadio_ScanningMedia = ConstComVal.VAL_CONFIGDLG_RADIO_SM_CARD Then
				Dim errRet As ErrorCode = m_objDriverControl.ScanCard()
				If errRet <> ErrorCode.SUCCESS Then
					ShowErrorMessage(errRet)
					m_objDriverControl.CancelError()
					Return
				End If
			End If
		End Sub

		Private Sub btnExit_Click(sender As Object, e As EventArgs)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Close()
				Return
			End If

			Dim errRet As ErrorCode = m_objDriverControl.ExitDevice()
			If errRet <> ErrorCode.SUCCESS Then
				ShowErrorMessage(errRet)
			End If
			Close()
		End Sub

		Private Sub btnScanCancel_Click(sender As Object, e As EventArgs)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			Dim errRet As ErrorCode = m_objDriverControl.CancelScan()
			If errRet <> ErrorCode.SUCCESS Then
				m_bScanCancelError = True
				ShowErrorMessage(errRet)
				m_objDriverControl.CancelError()
			End If
		End Sub

		'''/////////////
		'''/ Step 2 ////
		'''/////////////

		Private Sub btnConfig_Click(sender As Object, e As EventArgs)
			Dim cConfigureDlg As New ConfigureForm()

			cConfigureDlg.SetConfigData(m_objConfigData)

			If cConfigureDlg.ShowDialog(Me) = DialogResult.OK Then
				cConfigureDlg.GetConfigData(m_objConfigData)

				'''/////////////
				'''/ Step 2 ////
				'''/////////////

				Dim objScanParam As New CScanParam()
				ConvertConfigDataToScanParam(m_objConfigData, objScanParam)
				If m_objDriverControl IsNot Nothing Then
					m_objDriverControl.SetScanParam(objScanParam)
				End If

				'''/////////////
				'''/ Step 3 ////
				'''/////////////

				Dim cMicrParam As New CMicrParam()
				ConvertConfigDataToMicrParam(m_objConfigData, cMicrParam)
				If m_objDriverControl IsNot Nothing Then
					m_objDriverControl.SetMicrParam(cMicrParam)
				End If

				'''/////////////
				'''/ Step 8 ////
				'''/////////////

				Dim cBarcodeParam As New CBarcodeParam()
				ConvertConfigDataToBarcodeParam(m_objConfigData, cBarcodeParam)
				If m_objDriverControl IsNot Nothing Then
					m_objDriverControl.SetBarcodeParam(cBarcodeParam)
				End If

				Dim cOptionParam As New COptionParam()
				ConvertConfigDataToOptionParam(m_objConfigData, cOptionParam)
				If m_objDriverControl IsNot Nothing Then
					m_objDriverControl.SetOptionParam(cOptionParam)
				End If

				UpdateControls()
			End If
		End Sub

		'''/////////////
		'''/ Step 3 ////
		'''/////////////

		Private Sub btnMicrCleaning_Click(sender As Object, e As EventArgs)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			Dim errRet As ErrorCode = m_objDriverControl.CleaningMicr()
			If errRet <> ErrorCode.SUCCESS Then
				ShowErrorMessage(errRet)
				m_objDriverControl.CancelError()
			End If
		End Sub

		'''/////////////
		'''/ Step 8 ////
		'''/////////////

		Private Sub btnDeviceStatus_Click(sender As Object, e As EventArgs)
			If m_DeviceStatusDlg Is Nothing Then
				Debug.Assert(False)
				Return
			End If
			If Not m_DeviceStatusDlg.Visible Then
				m_DeviceStatusDlg.DisplayDeviceStatus(m_objDeviceStatus)
				m_DeviceStatusDlg.DisplayInkStatus(m_objInkStatus)

				m_DeviceStatusDlg.Show()
			Else
				m_DeviceStatusDlg.Hide()
			End If
		End Sub


		Private Sub btnDeviceInfo_Click(sender As Object, e As EventArgs)
			If m_DeviceInfoDlg Is Nothing Then
				Debug.Assert(False)
				Return
			End If
			If Not m_DeviceInfoDlg.Visible Then
				Dim errRet As ErrorCode = ErrorCode.SUCCESS

				Dim cDeviceInfo As New CDeviceInfo()
				errRet = m_objDriverControl.GetDeviceInfo(cDeviceInfo)
				If errRet = ErrorCode.SUCCESS Then
					m_DeviceInfoDlg.DisplayDeviceInfo(cDeviceInfo)
				Else
					ShowErrorMessage(errRet)
					m_objDriverControl.CancelError()
					Return
				End If

				Dim cMaintenanceCounter As New CMaintenanceCounter()
				errRet = m_objDriverControl.GetMaintenanceCounter(cMaintenanceCounter)
				If errRet = ErrorCode.SUCCESS Then
					m_DeviceInfoDlg.DisplayMaintenanceCounter(cMaintenanceCounter)
				Else
					ShowErrorMessage(errRet)
					m_objDriverControl.CancelError()
					Return
				End If
				m_DeviceInfoDlg.Show()
			Else
				m_DeviceInfoDlg.Hide()
			End If
		End Sub


		'''//////////////////////////////////////////////////////////////
		' Member functions
		'''//////////////////////////////////////////////////////////////

		Private Function InitializeDriver() As Boolean
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return False
			End If

			Dim errResult As ErrorCode = ErrorCode.SUCCESS
			Dim drRet As DialogResult = 0
			Dim strResult As String = Nothing

			' Open device and register callback functions
			errResult = m_objDriverControl.InitDevice()
			While errResult <> ErrorCode.SUCCESS
				If errResult = ErrorCode.ERR_UNKNOWN Then
					drRet = ShowMessage(ConstComStr.MSG_06_000, ConstComStr.CAPTION_06_000, MessageBoxButtons.OKCancel, MessageBoxIcon.[Error])
				Else
					strResult = GetErrorString(errResult)
					drRet = ShowMessage(ConstComStr.MSG_00_000, strResult, MessageBoxButtons.OKCancel, MessageBoxIcon.[Error])
				End If

				If drRet = DialogResult.OK Then
					errResult = m_objDriverControl.InitDevice()
				Else
					Return False
				End If
			End While

			' Specify callback function from DriverControl
			' Step 1
			m_objDriverControl.SetProcessErrorCallback(New CApp.CallbackProcProcessError(AddressOf CallbackProcProcessError))
			' Step 2
			m_objDriverControl.SetImageCallback(New CApp.CallbackProcImage(AddressOf CallbackProcImage))
			' Step 3
			m_objDriverControl.SetMicrCallback(New CApp.CallbackProcMicr(AddressOf CallbackProcMicr))
			' Step 8
			m_objDriverControl.SetBarcodeCallback(New CApp.CallbackProcBarcode(AddressOf CallbackProcBarcode))
			m_objDriverControl.SetDeviceStatusCallback(New CApp.CallbackProcDeviceStatus(AddressOf CallbackProcDeviceStatus))
			m_objDriverControl.SetInkStatusCallback(New CApp.CallbackProcInkStatus(AddressOf CallbackProcInkStatus))

			' Obtain connected device option
			' Step 2
			m_objConfigData.bIsScanningCardIR1PassSupported = m_objDriverControl.IsScanningCardIR1PassSupported()
			' Step 8
			' Get device status and ink status
			m_objDriverControl.GetDeviceStatusFunction(m_objDeviceStatus)
			m_objDriverControl.GetInkStatusFunction(m_objInkStatus)

			Return True
		End Function

		Private Function TerminateDriver() As ErrorCode
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return ErrorCode.ERR_NO_MEMORY
			End If

			Dim errRet As ErrorCode = m_objDriverControl.ExitDevice()
			If errRet <> ErrorCode.SUCCESS Then
				Return errRet
			End If

			Return errRet
		End Function

		Private Function ShowMessageImpl(text As String, caption As String, buttons As MessageBoxButtons, icon As MessageBoxIcon) As DialogResult
			If Me.InvokeRequired Then
				Return CType(Me.Invoke(ShowMessage, New Object() {text, caption, buttons, icon}), DialogResult)
			End If
			Return MessageBox.Show(text, caption, buttons, icon)
		End Function

		Private Sub ShowErrorMessageImpl(errResult As ErrorCode)
			If Me.InvokeRequired Then
				Me.Invoke(ShowErrorMessage, New Object() {errResult})
				Return
			End If

			Select Case errResult
				Case ErrorCode.ERR_TYPE
					MessageBox.Show(ConstComStr.MSG_03_000, ConstComStr.CAPTION_03_000, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_OPENED
					MessageBox.Show(ConstComStr.MSG_03_001, ConstComStr.CAPTION_03_001, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NO_PRINTER
					MessageBox.Show(ConstComStr.MSG_03_002, ConstComStr.CAPTION_03_002, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NO_TARGET
					MessageBox.Show(ConstComStr.MSG_03_003, ConstComStr.CAPTION_03_003, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NO_MEMORY
					MessageBox.Show(ConstComStr.MSG_03_004, ConstComStr.CAPTION_03_004, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_HANDLE
					MessageBox.Show(ConstComStr.MSG_03_005, ConstComStr.CAPTION_03_005, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_TIMEOUT
					MessageBox.Show(ConstComStr.MSG_03_006, ConstComStr.CAPTION_03_006, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_ACCESS
					MessageBox.Show(ConstComStr.MSG_03_007, ConstComStr.CAPTION_03_007, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PARAM
					MessageBox.Show(ConstComStr.MSG_03_008, ConstComStr.CAPTION_03_008, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NOT_SUPPORT
					MessageBox.Show(ConstComStr.MSG_03_009, ConstComStr.CAPTION_03_009, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_OFFLINE
					MessageBox.Show(ConstComStr.MSG_03_010, ConstComStr.CAPTION_03_010, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NOT_EPSON
					MessageBox.Show(ConstComStr.MSG_03_011, ConstComStr.CAPTION_03_011, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_WITHOUT_CB
					If m_bScanCancelError = True Then
						MessageBox.Show(ConstComStr.MSG_03_012_01, ConstComStr.CAPTION_03_012, MessageBoxButtons.OK, MessageBoxIcon.Warning)
						m_bScanCancelError = False
					Else
						MessageBox.Show(ConstComStr.MSG_03_012_00, ConstComStr.CAPTION_03_012, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					End If
					Exit Select
				Case ErrorCode.ERR_BUFFER_OVER_FLOW
					MessageBox.Show(ConstComStr.MSG_03_013, ConstComStr.CAPTION_03_013, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_REGISTRY
					MessageBox.Show(ConstComStr.MSG_03_014, ConstComStr.CAPTION_03_014, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPERINSERT_TIMEOUT
					MessageBox.Show(ConstComStr.MSG_03_015, ConstComStr.CAPTION_03_015, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_FUNCTION
					MessageBox.Show(ConstComStr.MSG_03_016, ConstComStr.CAPTION_03_016, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_MICR
					MessageBox.Show(ConstComStr.MSG_03_017, ConstComStr.CAPTION_03_017, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_SCAN
					MessageBox.Show(ConstComStr.MSG_03_018, ConstComStr.CAPTION_03_018, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_RESET
					MessageBox.Show(ConstComStr.MSG_03_019, ConstComStr.CAPTION_03_019, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_ABORT
					MessageBox.Show(ConstComStr.MSG_03_020, ConstComStr.CAPTION_03_020, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR
					MessageBox.Show(ConstComStr.MSG_03_021, ConstComStr.CAPTION_03_021, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_SCAN
					MessageBox.Show(ConstComStr.MSG_03_022, ConstComStr.CAPTION_03_022, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_LINE_OVERFLOW
					MessageBox.Show(ConstComStr.MSG_03_023, ConstComStr.CAPTION_03_023, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPER_PILED
					MessageBox.Show(ConstComStr.MSG_03_024, ConstComStr.CAPTION_03_024, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPER_JAM
					MessageBox.Show(ConstComStr.MSG_03_025, ConstComStr.CAPTION_03_025, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_COVER_OPEN
					MessageBox.Show(ConstComStr.MSG_03_026, ConstComStr.CAPTION_03_026, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR_NODATA
					MessageBox.Show(ConstComStr.MSG_03_027, ConstComStr.CAPTION_03_027, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR_BADDATA
					MessageBox.Show(ConstComStr.MSG_03_028, ConstComStr.CAPTION_03_028, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR_NOISE
					MessageBox.Show(ConstComStr.MSG_03_029, ConstComStr.CAPTION_03_029, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_SCN_COMPRESS
					MessageBox.Show(ConstComStr.MSG_03_030, ConstComStr.CAPTION_03_030, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPER_EXIST
					MessageBox.Show(ConstComStr.MSG_03_031, ConstComStr.CAPTION_03_031, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PAPER_INSERT
					MessageBox.Show(ConstComStr.MSG_03_032, ConstComStr.CAPTION_03_032, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_SCAN_CHECK_CONTINUOUS
					MessageBox.Show(ConstComStr.MSG_03_033, ConstComStr.CAPTION_03_033, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_SCAN_CHECK_ONEBYONE
					MessageBox.Show(ConstComStr.MSG_03_034, ConstComStr.CAPTION_03_034, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_SCAN_IDCARD
					MessageBox.Show(ConstComStr.MSG_03_035, ConstComStr.CAPTION_03_035, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_PRINT_ROLLPAPER
					MessageBox.Show(ConstComStr.MSG_03_036, ConstComStr.CAPTION_03_036, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_EXEC_PRINT_VALIDATION
					MessageBox.Show(ConstComStr.MSG_03_037, ConstComStr.CAPTION_03_037, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_THREAD
					MessageBox.Show(ConstComStr.MSG_03_038, ConstComStr.CAPTION_03_038, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_IMAGE_FILEOPEN
					MessageBox.Show(ConstComStr.MSG_03_039, ConstComStr.CAPTION_03_039, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_IMAGE_UNKNOWNFORMAT
					MessageBox.Show(ConstComStr.MSG_03_040, ConstComStr.CAPTION_03_040, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_SIZE
					MessageBox.Show(ConstComStr.MSG_03_041, ConstComStr.CAPTION_03_041, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NOT_FOUND
					MessageBox.Show(ConstComStr.MSG_03_042, ConstComStr.CAPTION_03_042, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_NOT_EXEC
					MessageBox.Show(ConstComStr.MSG_03_043, ConstComStr.CAPTION_03_043, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_BARCODE_NODATA
					MessageBox.Show(ConstComStr.MSG_03_044, ConstComStr.CAPTION_03_044, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_MICR_PARSE
					MessageBox.Show(ConstComStr.MSG_03_045, ConstComStr.CAPTION_03_045, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_SCN_IQA
					MessageBox.Show(ConstComStr.MSG_03_046, ConstComStr.CAPTION_03_046, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PRINT_DATA_LENGTH_EXCEED
					MessageBox.Show(ConstComStr.MSG_03_047, ConstComStr.CAPTION_03_047, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_PRINT_DATA_UNRECEIVE
					MessageBox.Show(ConstComStr.MSG_03_048, ConstComStr.CAPTION_03_048, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_INK_STATUS
					MessageBox.Show(ConstComStr.MSG_03_050, ConstComStr.CAPTION_03_051, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case ErrorCode.ERR_IMAGE_FILEREAD
					MessageBox.Show(ConstComStr.MSG_03_049, ConstComStr.CAPTION_03_049, MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
				Case Else
					MessageBox.Show(errResult.ToString(), "ERR", MessageBoxButtons.OK, MessageBoxIcon.Warning)
					Exit Select
			End Select
		End Sub

		Private Function GetErrorString(errResultCode As ErrorCode) As String
			Select Case errResultCode
				Case ErrorCode.SUCCESS
					Return ConstComStr.CAPTION_00_000
				Case ErrorCode.ERR_TYPE
					Return ConstComStr.CAPTION_03_000
				Case ErrorCode.ERR_OPENED
					Return ConstComStr.CAPTION_03_001
				Case ErrorCode.ERR_NO_PRINTER
					Return ConstComStr.CAPTION_03_002
				Case ErrorCode.ERR_NO_TARGET
					Return ConstComStr.CAPTION_03_003
				Case ErrorCode.ERR_NO_MEMORY
					Return ConstComStr.CAPTION_03_004
				Case ErrorCode.ERR_HANDLE
					Return ConstComStr.CAPTION_03_005
				Case ErrorCode.ERR_TIMEOUT
					Return ConstComStr.CAPTION_03_006
				Case ErrorCode.ERR_ACCESS
					Return ConstComStr.CAPTION_03_007
				Case ErrorCode.ERR_PARAM
					Return ConstComStr.CAPTION_03_008
				Case ErrorCode.ERR_NOT_SUPPORT
					Return ConstComStr.CAPTION_03_009
				Case ErrorCode.ERR_OFFLINE
					Return ConstComStr.CAPTION_03_010
				Case ErrorCode.ERR_NOT_EPSON
					Return ConstComStr.CAPTION_03_011
				Case ErrorCode.ERR_WITHOUT_CB
					Return ConstComStr.CAPTION_03_012
				Case ErrorCode.ERR_BUFFER_OVER_FLOW
					Return ConstComStr.CAPTION_03_013
				Case ErrorCode.ERR_REGISTRY
					Return ConstComStr.CAPTION_03_014
				Case ErrorCode.ERR_PAPERINSERT_TIMEOUT
					Return ConstComStr.CAPTION_03_015
				Case ErrorCode.ERR_EXEC_FUNCTION
					Return ConstComStr.CAPTION_03_016
				Case ErrorCode.ERR_EXEC_MICR
					Return ConstComStr.CAPTION_03_017
				Case ErrorCode.ERR_EXEC_SCAN
					Return ConstComStr.CAPTION_03_018
				Case ErrorCode.ERR_RESET
					Return ConstComStr.CAPTION_03_019
				Case ErrorCode.ERR_ABORT
					Return ConstComStr.CAPTION_03_020
				Case ErrorCode.ERR_MICR
					Return ConstComStr.CAPTION_03_021
				Case ErrorCode.ERR_SCAN
					Return ConstComStr.CAPTION_03_022
				Case ErrorCode.ERR_LINE_OVERFLOW
					Return ConstComStr.CAPTION_03_023
				Case ErrorCode.ERR_PAPER_PILED
					Return ConstComStr.CAPTION_03_024
				Case ErrorCode.ERR_PAPER_JAM
					Return ConstComStr.CAPTION_03_025
				Case ErrorCode.ERR_COVER_OPEN
					Return ConstComStr.CAPTION_03_026
				Case ErrorCode.ERR_MICR_NODATA
					Return ConstComStr.CAPTION_03_027
				Case ErrorCode.ERR_MICR_BADDATA
					Return ConstComStr.CAPTION_03_028
				Case ErrorCode.ERR_MICR_NOISE
					Return ConstComStr.CAPTION_03_029
				Case ErrorCode.ERR_SCN_COMPRESS
					Return ConstComStr.CAPTION_03_030
				Case ErrorCode.ERR_PAPER_EXIST
					Return ConstComStr.CAPTION_03_031
				Case ErrorCode.ERR_PAPER_INSERT
					Return ConstComStr.CAPTION_03_032
				Case ErrorCode.ERR_EXEC_SCAN_CHECK_CONTINUOUS
					Return ConstComStr.CAPTION_03_033
				Case ErrorCode.ERR_EXEC_SCAN_CHECK_ONEBYONE
					Return ConstComStr.CAPTION_03_034
				Case ErrorCode.ERR_EXEC_SCAN_IDCARD
					Return ConstComStr.CAPTION_03_035
				Case ErrorCode.ERR_EXEC_PRINT_ROLLPAPER
					Return ConstComStr.CAPTION_03_036
				Case ErrorCode.ERR_EXEC_PRINT_VALIDATION
					Return ConstComStr.CAPTION_03_037
				Case ErrorCode.ERR_THREAD
					Return ConstComStr.CAPTION_03_038
				Case ErrorCode.ERR_IMAGE_FILEOPEN
					Return ConstComStr.CAPTION_03_039
				Case ErrorCode.ERR_IMAGE_UNKNOWNFORMAT
					Return ConstComStr.CAPTION_03_040
				Case ErrorCode.ERR_SIZE
					Return ConstComStr.CAPTION_03_041
				Case ErrorCode.ERR_NOT_FOUND
					Return ConstComStr.CAPTION_03_042
				Case ErrorCode.ERR_NOT_EXEC
					Return ConstComStr.CAPTION_03_043
				Case ErrorCode.ERR_BARCODE_NODATA
					Return ConstComStr.CAPTION_03_044
				Case ErrorCode.ERR_MICR_PARSE
					Return ConstComStr.CAPTION_03_045
				Case ErrorCode.ERR_SCN_IQA
					Return ConstComStr.CAPTION_03_046
				Case ErrorCode.ERR_PRINT_DATA_LENGTH_EXCEED
					Return ConstComStr.CAPTION_03_047
				Case ErrorCode.ERR_PRINT_DATA_UNRECEIVE
					Return ConstComStr.CAPTION_03_048
				Case ErrorCode.ERR_INK_STATUS
					Return ConstComStr.CAPTION_03_051
				Case ErrorCode.ERR_IMAGE_FILEREAD
					Return ConstComStr.CAPTION_03_049
				Case Else
					Return errResultCode.ToString()
			End Select
		End Function

		' Step 2
		Private Sub InitializeConfigData()
			If m_objConfigData Is Nothing Then
				Return
			End If

			'''/////////////
			'''/ Step 2 ////
			'''/////////////

			Dim objScanParam As New CScanParam()
			m_objDriverControl.GetScanParam(objScanParam)
			ConvertScanParamToConfigData(objScanParam, m_objConfigData)

			'''/////////////
			'''/ Step 3 ////
			'''/////////////

			Dim cMicrParam As New CMicrParam()
			m_objDriverControl.GetMicrParam(cMicrParam)
			ConvertMicrParamToConfigData(cMicrParam, m_objConfigData)

			'''/////////////
			'''/ Step 8 ////
			'''/////////////

			Dim cBarcodeParam As New CBarcodeParam()
			m_objDriverControl.GetBarcodeParam(cBarcodeParam)
			ConvertBarcodeParamToConfigData(cBarcodeParam, m_objConfigData)

			Dim cOptionParam As New COptionParam()
			m_objDriverControl.GetOptionParam(cOptionParam)
			ConvertOptionParamToConfigData(cOptionParam, m_objConfigData)
		End Sub

		Private Sub LoadResourceString()
			'''/////////////
			'''/ Step 1 ////
			'''/////////////

			' Title
			Me.Text = ConstComStr.STR_SAMPLEDLG_TITLE

			' Scan Button
			btnScan.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_SCAN

			' ScanCancel Button
			btnScanCancel.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_SCANCANCEL

			' Exit Button
			btnExit.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_EXIT

			'''/////////////
			'''/ Step 2 ////
			'''/////////////

			' Config Button
			btnConfig.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_CONFIG

			'''/////////////
			'''/ Step 3 ////
			'''/////////////

			' MICR Text Static
			stMicrText.Text = ConstComStr.STR_SAMPLEDLG_STATIC_MICRTEXT

			' Micr Cleaning Button
			btnMicrCleaning.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_MICRCLEANING

			'''/////////////
			'''/ Step 8 ////
			'''/////////////

			' Barcode Data Static
			stBarcodeData.Text = ConstComStr.STR_SAMPLEDLG_STATIC_BARCODEDATA

			' DeviceStatus Button
			btnDeviceStatus.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_DEVICESTATUS

			' DeviceInfo Button
			btnDeviceInfo.Text = ConstComStr.STR_SAMPLEDLG_BUTTON_DEVICEINFO
		End Sub

		Private Sub UpdateControls()
			'''/////////////
			'''/ Step 2 ////
			'''/////////////

			If m_objConfigData.nRadio_LightSourceToScan = ConstComVal.VAL_CONFIGDLG_RADIO_IC_RGBIR Then
				stImage2Front.Visible = False
				stImage2Back.Visible = False
				stImage4RGBFront.Visible = True
				stImage4RGBBack.Visible = True
				stImage4IRBack.Visible = True
				stImage4IRFront.Visible = True
			Else
				stImage2Front.Visible = True
				stImage2Back.Visible = True
				stImage4RGBFront.Visible = False
				stImage4RGBBack.Visible = False
				stImage4IRBack.Visible = False
				stImage4IRFront.Visible = False
			End If
		End Sub

		' Step 2
		Private Sub ConvertConfigDataToScanParam(objConfigData As StructByStep, ByRef objScanParam As CScanParam)
			If objScanParam Is Nothing OrElse objConfigData Is Nothing Then
				Debug.Assert(False)
				Return
			End If

			Select Case objConfigData.nRadio_ScanningMedia
				Case ConstComVal.VAL_CONFIGDLG_RADIO_SM_CHECKPAPER
					objScanParam.SetScanMedia(ScanUnit.EPS_BI_SCN_UNIT_CHECKPAPER)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_RADIO_SM_CARD
					objScanParam.SetScanMedia(ScanUnit.EPS_BI_SCN_UNIT_CARD)
					Exit Select
				Case Else
					Exit Select
			End Select

			Select Case objConfigData.nRadio_LightSourceToScan
				Case ConstComVal.VAL_CONFIGDLG_RADIO_IC_RGB
					If objConfigData.nRadio_RGBColorDepth = ConstComVal.VAL_CONFIGDLG_RADIO_RGBCD_COLOR Then
						objScanParam.SetLightSourceToScan(ImageTypeOption.EPS_BI_SCN_OPTION_COLOR)
					Else
						objScanParam.SetLightSourceToScan(ImageTypeOption.EPS_BI_SCN_OPTION_GRAYSCALE)
					End If
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_RADIO_IC_IR
					objScanParam.SetLightSourceToScan(ImageTypeOption.EPS_BI_SCN_OPTION_IR)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_RADIO_IC_RGBIR
					If objConfigData.nRadio_RGBColorDepth = ConstComVal.VAL_CONFIGDLG_RADIO_RGBCD_COLOR Then
						objScanParam.SetLightSourceToScan(ImageTypeOption.EPS_BI_SCN_OPTION_COLOR_IR)
					Else
						objScanParam.SetLightSourceToScan(ImageTypeOption.EPS_BI_SCN_OPTION_GRAYSCALE_IR)
					End If
					Exit Select
				Case Else
					Exit Select
			End Select

			Select Case objConfigData.nRadio_RGBColorDepth
				Case ConstComVal.VAL_CONFIGDLG_RADIO_RGBCD_COLOR
					objScanParam.SetRGBColorDepth(com.epson.bank.driver.ColorDepth.EPS_BI_SCN_24BIT)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_RADIO_RGBCD_GRAY
					objScanParam.SetRGBColorDepth(com.epson.bank.driver.ColorDepth.EPS_BI_SCN_8BIT)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_RADIO_RGBCD_BW
					objScanParam.SetRGBColorDepth(com.epson.bank.driver.ColorDepth.EPS_BI_SCN_1BIT)
					Exit Select
				Case Else
					Exit Select
			End Select

			Select Case objConfigData.nRadio_IRColorDepth
				Case ConstComVal.VAL_CONFIGDLG_RADIO_IRCD_GRAY
					objScanParam.SetIRColorDepth(com.epson.bank.driver.ColorDepth.EPS_BI_SCN_8BIT)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_RADIO_IRCD_BW
					objScanParam.SetIRColorDepth(com.epson.bank.driver.ColorDepth.EPS_BI_SCN_1BIT)
					Exit Select
				Case Else
					Exit Select
			End Select

			Select Case objConfigData.nCombo_Resolution
				Case ConstComVal.VAL_CONFIGDLG_COMBO_RE_600600
					objScanParam.SetResolution(MfScanDpi.MF_SCAN_DPI_600)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_RE_300300
					objScanParam.SetResolution(MfScanDpi.MF_SCAN_DPI_300)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_RE_240240
					objScanParam.SetResolution(MfScanDpi.MF_SCAN_DPI_240)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_RE_200200
					objScanParam.SetResolution(MfScanDpi.MF_SCAN_DPI_200)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_RE_120120
					objScanParam.SetResolution(MfScanDpi.MF_SCAN_DPI_120)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_RE_100100
					objScanParam.SetResolution(MfScanDpi.MF_SCAN_DPI_100)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			objScanParam.SetNumberOfDocuments(objConfigData.byNumeric_NumberOfDocuments)
		End Sub

		' Step 3
		Private Sub ConvertConfigDataToMicrParam(objConfigData As StructByStep, ByRef objMicrParam As CMicrParam)
			If objMicrParam Is Nothing OrElse objConfigData Is Nothing Then
				Debug.Assert(False)
				Return
			End If

			Select Case objConfigData.nRadio_MICRFont
				Case ConstComVal.VAL_CONFIGDLG_RADIO_MF_E13B
					objMicrParam.SetFont(MfMicrFont.MF_MICR_FONT_E13B)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_RADIO_MF_CMC7
					objMicrParam.SetFont(MfMicrFont.MF_MICR_FONT_CMC7)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.bCheck_MICR_ClearSpace
				Case ConstComVal.VAL_CONFIGDLG_CHECK_MI_CLEARSPACE_ON
					objMicrParam.SetClearSpace(True)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_MI_CLEARSPACE_OFF
					objMicrParam.SetClearSpace(False)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.bCheck_MICR_SaveFile
				Case ConstComVal.VAL_CONFIGDLG_CHECK_MI_SAVEFILE_ON
					objMicrParam.SetParsing(True)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_MI_SAVEFILE_OFF
					objMicrParam.SetParsing(False)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select
		End Sub

		' Step 2
		Private Sub ConvertScanParamToConfigData(objScanParam As CScanParam, ByRef objConfigData As StructByStep)
			If objScanParam Is Nothing OrElse objConfigData Is Nothing Then
				Debug.Assert(False)
				Return
			End If

			Select Case objScanParam.GetScanMedia()
				Case ScanUnit.EPS_BI_SCN_UNIT_CHECKPAPER
					objConfigData.nRadio_ScanningMedia = ConstComVal.VAL_CONFIGDLG_RADIO_SM_CHECKPAPER
					Exit Select
				Case ScanUnit.EPS_BI_SCN_UNIT_CARD
					objConfigData.nRadio_ScanningMedia = ConstComVal.VAL_CONFIGDLG_RADIO_SM_CARD
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objScanParam.GetLightSourceToScan()
				Case ImageTypeOption.EPS_BI_SCN_OPTION_COLOR, ImageTypeOption.EPS_BI_SCN_OPTION_GRAYSCALE, ImageTypeOption.EPS_BI_SCN_OPTION_DROPOUT_RED, ImageTypeOption.EPS_BI_SCN_OPTION_DROPOUT_GREEN, ImageTypeOption.EPS_BI_SCN_OPTION_DROPOUT_BLUE
					objConfigData.nRadio_LightSourceToScan = ConstComVal.VAL_CONFIGDLG_RADIO_IC_RGB
					Exit Select
				Case ImageTypeOption.EPS_BI_SCN_OPTION_IR
					objConfigData.nRadio_LightSourceToScan = ConstComVal.VAL_CONFIGDLG_RADIO_IC_IR
					Exit Select
				Case ImageTypeOption.EPS_BI_SCN_OPTION_COLOR_IR, ImageTypeOption.EPS_BI_SCN_OPTION_GRAYSCALE_IR, ImageTypeOption.EPS_BI_SCN_OPTION_DROPOUT_RED_IR, ImageTypeOption.EPS_BI_SCN_OPTION_DROPOUT_GREEN_IR, ImageTypeOption.EPS_BI_SCN_OPTION_DROPOUT_BLUE_IR
					objConfigData.nRadio_LightSourceToScan = ConstComVal.VAL_CONFIGDLG_RADIO_IC_RGBIR
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objScanParam.GetRGBColorDepth()
				Case com.epson.bank.driver.ColorDepth.EPS_BI_SCN_24BIT
					objConfigData.nRadio_RGBColorDepth = ConstComVal.VAL_CONFIGDLG_RADIO_RGBCD_COLOR
					Exit Select
				Case com.epson.bank.driver.ColorDepth.EPS_BI_SCN_8BIT
					objConfigData.nRadio_RGBColorDepth = ConstComVal.VAL_CONFIGDLG_RADIO_RGBCD_GRAY
					Exit Select
				Case com.epson.bank.driver.ColorDepth.EPS_BI_SCN_1BIT
					objConfigData.nRadio_RGBColorDepth = ConstComVal.VAL_CONFIGDLG_RADIO_RGBCD_BW
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objScanParam.GetIRColorDepth()
				Case com.epson.bank.driver.ColorDepth.EPS_BI_SCN_8BIT
					objConfigData.nRadio_IRColorDepth = ConstComVal.VAL_CONFIGDLG_RADIO_IRCD_GRAY
					Exit Select
				Case com.epson.bank.driver.ColorDepth.EPS_BI_SCN_1BIT
					objConfigData.nRadio_IRColorDepth = ConstComVal.VAL_CONFIGDLG_RADIO_IRCD_BW
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objScanParam.GetResolution()
				Case MfScanDpi.MF_SCAN_DPI_600
					objConfigData.nCombo_Resolution = ConstComVal.VAL_CONFIGDLG_COMBO_RE_600600
					Exit Select
				Case MfScanDpi.MF_SCAN_DPI_300
					objConfigData.nCombo_Resolution = ConstComVal.VAL_CONFIGDLG_COMBO_RE_300300
					Exit Select
				Case MfScanDpi.MF_SCAN_DPI_240
					objConfigData.nCombo_Resolution = ConstComVal.VAL_CONFIGDLG_COMBO_RE_240240
					Exit Select
				Case MfScanDpi.MF_SCAN_DPI_200
					objConfigData.nCombo_Resolution = ConstComVal.VAL_CONFIGDLG_COMBO_RE_200200
					Exit Select
				Case MfScanDpi.MF_SCAN_DPI_120
					objConfigData.nCombo_Resolution = ConstComVal.VAL_CONFIGDLG_COMBO_RE_120120
					Exit Select
				Case MfScanDpi.MF_SCAN_DPI_100
					objConfigData.nCombo_Resolution = ConstComVal.VAL_CONFIGDLG_COMBO_RE_100100
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			objConfigData.byNumeric_NumberOfDocuments = objScanParam.GetNumberOfDocuments()
		End Sub

		' Step 3
		Private Sub ConvertMicrParamToConfigData(objMicrParam As CMicrParam, ByRef objConfigData As StructByStep)
			If objMicrParam Is Nothing OrElse objConfigData Is Nothing Then
				Debug.Assert(False)
				Return
			End If

			Select Case objMicrParam.GetFont()
				Case MfMicrFont.MF_MICR_FONT_E13B
					objConfigData.nRadio_MICRFont = ConstComVal.VAL_CONFIGDLG_RADIO_MF_E13B
					Exit Select
				Case MfMicrFont.MF_MICR_FONT_CMC7
					objConfigData.nRadio_MICRFont = ConstComVal.VAL_CONFIGDLG_RADIO_MF_CMC7
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			If objMicrParam.GetClearSpace() = True Then
				objConfigData.bCheck_MICR_ClearSpace = ConstComVal.VAL_CONFIGDLG_CHECK_MI_CLEARSPACE_ON
			Else
				objConfigData.bCheck_MICR_ClearSpace = ConstComVal.VAL_CONFIGDLG_CHECK_MI_CLEARSPACE_OFF
			End If
		End Sub

		' Step 2
		Private Function PrepareFolder() As String
			Dim strPath As String = Path.Combine(Directory.GetCurrentDirectory(), "ScanResult")
			Directory.CreateDirectory(strPath)
			Return strPath
		End Function

		Private Sub UpdateImageData(eFace As ScanSide, eLightSource As ImageType, eResolution As MfScanDpi, eColorDepth As com.epson.bank.driver.ColorDepth, ByRef Image As Bitmap, bSave As Boolean)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			Dim cImageResult As New CImageResult()

			' Obtain image data
			cImageResult.SetFace(eFace)
			cImageResult.SetLightSource(eLightSource)
			cImageResult.SetResolution(eResolution)
			cImageResult.SetColorDepth(eColorDepth)

			' Show image on the window
			If True Then
				cImageResult.SetFormat(Format.EPS_BI_SCN_BITMAP)
				Dim errResult As ErrorCode = m_objDriverControl.GetScanImage(cImageResult)
				If errResult <> ErrorCode.SUCCESS Then
					ShowErrorMessage(errResult)
					Return
				End If

				Image = New Bitmap(cImageResult.GetBitmapImage())
			End If
			' Save image
			If bSave Then
				' Specify image data format
				Dim strExt As String
				If eColorDepth = com.epson.bank.driver.ColorDepth.EPS_BI_SCN_1BIT Then
					cImageResult.SetFormat(Format.EPS_BI_SCN_TIFF)
					strExt = "tif"
				Else
					cImageResult.SetFormat(Format.EPS_BI_SCN_JPEGNORMAL)
					strExt = "jpg"
				End If

				' Obtain image data
				Dim errResult As ErrorCode = m_objDriverControl.GetScanImage(cImageResult)
				If errResult <> ErrorCode.SUCCESS Then
					ShowErrorMessage(errResult)
					Return
				End If

				Try
					If cImageResult.GetImageData() IsNot Nothing Then
						Dim cImage As Stream = cImageResult.GetImageData()
						Dim nImageSize As Integer = cImageResult.GetImageSize()
						Dim nTransactionNumber As Integer = cImageResult.GetTransactionNumber()

						' Prepare folder to store data
						Dim strPath As String = PrepareFolder()
						' may throw
						' Compose file name
						strPath = Path.Combine(strPath, nTransactionNumber.ToString("000") & ("_Image_") & (If(cImageResult.GetLightSource() = ImageType.MF_SCAN_IMAGE_INFRARED, "IR_", "")) & (If(cImageResult.GetFace() = ScanSide.MF_SCAN_FACE_BACK, "Back", "Front")) & (".") & strExt)

						' Save in file
						Using fs As New FileStream(strPath, FileMode.Create)
							Dim byBuffer As Byte() = New Byte(cImageResult.GetImageSize() - 1) {}

							cImageResult.GetImageData().Read(byBuffer, 0, byBuffer.Length)
							fs.Write(byBuffer, 0, byBuffer.Length)
							cImageResult.GetImageData().Close()
						End Using
					End If
				Catch
					ShowMessage(ConstComStr.MSG_05_000, ConstComStr.CAPTION_05_000, MessageBoxButtons.OK, MessageBoxIcon.[Error])
					Return
				End Try
			End If
		End Sub

		Private Sub ClearImage()
			If stImage2Front.Image IsNot Nothing Then
				stImage2Front.Image.Dispose()
				stImage2Front.Image = Nothing
				m_Image2Front = Nothing
			End If
			If stImage2Back.Image IsNot Nothing Then
				stImage2Back.Image.Dispose()
				stImage2Back.Image = Nothing
				m_Image2Back = Nothing
			End If
			If stImage4RGBFront.Image IsNot Nothing Then
				stImage4RGBFront.Image.Dispose()
				stImage4RGBFront.Image = Nothing
				m_Image4RGBFront = Nothing
			End If
			If stImage4RGBBack.Image IsNot Nothing Then
				stImage4RGBBack.Image.Dispose()
				stImage4RGBBack.Image = Nothing
				m_Image4RGBBack = Nothing
			End If
			If stImage4IRBack.Image IsNot Nothing Then
				stImage4IRBack.Image.Dispose()
				stImage4IRBack.Image = Nothing
				m_Image4IrBack = Nothing
			End If
			If stImage4IRFront.Image IsNot Nothing Then
				stImage4IRFront.Image.Dispose()
				stImage4IRFront.Image = Nothing
				m_Image4IrFront = Nothing
			End If
		End Sub

		Private Sub DrawImage(stImage As PictureBox, biImage As Bitmap)
			If stImage.Image IsNot Nothing Then
				stImage.Image.Dispose()
			End If
			If biImage Is Nothing Then
				Return
			End If

			Dim nWidth As Integer = 0
			Dim nHeight As Integer = 0

			If (biImage.Width * stImage.Height) < (stImage.Width * biImage.Height) Then
				nWidth = stImage.Height * biImage.Width \ biImage.Height
				stImage.Image = New Bitmap(biImage, nWidth, stImage.Height)
			Else
				nHeight = stImage.Width * biImage.Height \ biImage.Width
				stImage.Image = New Bitmap(biImage, stImage.Width, nHeight)
			End If
		End Sub

		' Step 3
		Private Sub SaveMicrText(errResult As ErrorCode, cMicrResult As CMicrResult)
			Debug.Assert(m_objDriverControl IsNot Nothing)
			If m_objDriverControl Is Nothing Then
				Return
			End If

			' Obtain MICR data
			Dim nTransactionNumber As Integer = cMicrResult.GetTransactionNumber()

			If errResult <> ErrorCode.SUCCESS Then
				ShowErrorMessage(errResult)
				Return
			End If

			Try
				' Prepare folder to store data
				Dim strPath As String = PrepareFolder()
				' may throw
				' Compose file name
				strPath = Path.Combine(strPath, nTransactionNumber.ToString("000") & ".Micr.txt")

				Using swFile As New StreamWriter(strPath)
					' Transaction number
					swFile.WriteLine("# General Transaction Information:")
					swFile.WriteLine("TransactionNumber = " & nTransactionNumber.ToString())

					' MICR reading status
					swFile.WriteLine("")
					swFile.WriteLine("# Magnetic Character Results:")
					swFile.WriteLine("Status = " & cMicrResult.GetStatus().ToString())

					' Detail MICR reading status
					swFile.WriteLine("Detail = " & cMicrResult.GetDetail().ToString())

					' Return value from MICR recognition
					swFile.WriteLine("MicrResult = " & GetErrorString(cMicrResult.GetResult()))

					' Obtained MICR strings
					swFile.WriteLine("MicrString = " & (If(cMicrResult.GetMicrStr() IsNot Nothing, cMicrResult.GetMicrStr(), "")))

					'MicrAccountNumber
					swFile.WriteLine("MicrAccountNumber = " & (If(cMicrResult.GetAccountNumber() IsNot Nothing, cMicrResult.GetAccountNumber(), "")))

					'MicrAmount
					swFile.WriteLine("MicrAmount        = " & (If(cMicrResult.GetAmount() IsNot Nothing, cMicrResult.GetAmount(), "")))

					'MicrBankNumber
					swFile.WriteLine("MicrBankNumber    = " & (If(cMicrResult.GetBankNumber() IsNot Nothing, cMicrResult.GetBankNumber(), "")))

					'MicrSerialNumber
					swFile.WriteLine("MicrSerialNumber  = " & (If(cMicrResult.GetSerialNumber() IsNot Nothing, cMicrResult.GetSerialNumber(), "")))

					'MicrEPC
					swFile.WriteLine("MicrEPC           = " & (If(cMicrResult.GetEPC() IsNot Nothing, cMicrResult.GetEPC(), "")))

					' MicrTransitNumber
					swFile.WriteLine("MicrTransitNumber = " & (If(cMicrResult.GetTransitNumber() IsNot Nothing, cMicrResult.GetTransitNumber(), "")))

					' MicrCheckType
					swFile.WriteLine("MicrCheckType     = " & cMicrResult.GetCheckType().ToString())

					' MicrCountryCode
					swFile.WriteLine("MicrCountryCode     = " & cMicrResult.GetCountryCode().ToString())

					' MicrOnUSField
					swFile.WriteLine("MicrOnUSField = " & (If(cMicrResult.GetOnUSField() IsNot Nothing, cMicrResult.GetOnUSField(), "")))

					' MicrAuxiliatyOnUSField
					swFile.WriteLine("MicrAuxiliatyOnUSField = " & (If(cMicrResult.GetAuxiliatyOnUSField() IsNot Nothing, cMicrResult.GetAuxiliatyOnUSField(), "")))
				End Using
			Catch
				ShowMessage(ConstComStr.MSG_05_001, ConstComStr.CAPTION_05_001, MessageBoxButtons.OK, MessageBoxIcon.[Error])
				Return
			End Try
		End Sub

		'''/////////////
		'''/ Step 8 ////
		'''/////////////

		Private Sub ConvertConfigDataToBarcodeParam(objConfigData As StructByStep, ByRef objBarcodeParam As CBarcodeParam)
			If objBarcodeParam Is Nothing OrElse objConfigData Is Nothing Then
				Debug.Assert(False)
				Return
			End If

			Dim eBarcodeTypeMask As MfBarcodeSymbol = 0
			If objConfigData.bCheck_BT_SymbolCodabar Then
				eBarcodeTypeMask = eBarcodeTypeMask Or MfBarcodeSymbol.MF_BARCODE_SYMBOL_CODABAR
			End If
			If objConfigData.bCheck_BT_SymbolCode128 Then
				eBarcodeTypeMask = eBarcodeTypeMask Or MfBarcodeSymbol.MF_BARCODE_SYMBOL_CODE128
			End If
			If objConfigData.bCheck_BT_SymbolCode39 Then
				eBarcodeTypeMask = eBarcodeTypeMask Or MfBarcodeSymbol.MF_BARCODE_SYMBOL_CODE39
			End If
			If objConfigData.bCheck_BT_SymbolITF Then
				eBarcodeTypeMask = eBarcodeTypeMask Or MfBarcodeSymbol.MF_BARCODE_SYMBOL_ITF
			End If
			If objConfigData.bCheck_BT_SymbolEAN Then
				eBarcodeTypeMask = eBarcodeTypeMask Or MfBarcodeSymbol.MF_BARCODE_SYMBOL_EAN_JAN
			End If
			If objConfigData.bCheck_BT_SymbolUPCA Then
				eBarcodeTypeMask = eBarcodeTypeMask Or MfBarcodeSymbol.MF_BARCODE_SYMBOL_UPC_A
			End If
			objBarcodeParam.SetBarcodeTypeMask(eBarcodeTypeMask)

			Select Case objConfigData.bCheck_BA_Detect
				Case ConstComVal.VAL_CONFIGDLG_CHECK_BA_DETECT_OFF
					objBarcodeParam.SetBarcodeDetect(MfErrorSelect.MF_ERROR_SELECT_NODETECT)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_BA_DETECT_ON
					objBarcodeParam.SetBarcodeDetect(MfErrorSelect.MF_ERROR_SELECT_DETECT)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.bCheck_BA_Cancel
				Case ConstComVal.VAL_CONFIGDLG_CHECK_BA_CANCEL_OFF
					objBarcodeParam.SetBarcodeCancel(MfCancel.MF_CANCEL_DISABLE)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_BA_CANCEL_ON
					objBarcodeParam.SetBarcodeCancel(MfCancel.MF_CANCEL_ENABLE)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.nCombo_BA_EjectPocket
				Case ConstComVal.VAL_CONFIGDLG_COMBO_BA_EP_MAINPOCKET
					objBarcodeParam.SetBarcodeEject(MfEject.MF_EJECT_MAIN_POCKET)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_BA_EP_SUBPOCKET
					objBarcodeParam.SetBarcodeEject(MfEject.MF_EJECT_SUB_POCKET)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select
		End Sub

		Private Sub ConvertConfigDataToOptionParam(objConfigData As StructByStep, ByRef objOptionParam As COptionParam)
			If objOptionParam Is Nothing OrElse objConfigData Is Nothing Then
				Debug.Assert(False)
				Return
			End If

			' PaperMisInsertion
			Select Case objConfigData.bCheck_PI_Detect
				Case ConstComVal.VAL_CONFIGDLG_CHECK_PI_DETECT_OFF
					objOptionParam.SetPaperMisInsertionDetect(MfErrorSelect.MF_ERROR_SELECT_NODETECT)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_PI_DETECT_ON
					objOptionParam.SetPaperMisInsertionDetect(MfErrorSelect.MF_ERROR_SELECT_DETECT)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.bCheck_PI_Cancel
				Case ConstComVal.VAL_CONFIGDLG_CHECK_PI_CANCEL_OFF
					objOptionParam.SetPaperMisInsertionCancel(MfCancel.MF_CANCEL_DISABLE)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_PI_CANCEL_ON
					objOptionParam.SetPaperMisInsertionCancel(MfCancel.MF_CANCEL_ENABLE)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.nCombo_PI_EjectPocket
				Case ConstComVal.VAL_CONFIGDLG_COMBO_PI_EP_MAINPOCKET
					objOptionParam.SetPaperMisInsertionEject(MfEject.MF_EJECT_MAIN_POCKET)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_PI_EP_SUBPOCKET
					objOptionParam.SetPaperMisInsertionEject(MfEject.MF_EJECT_SUB_POCKET)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			' Noise
			Select Case objConfigData.bCheck_NO_Detect
				Case ConstComVal.VAL_CONFIGDLG_CHECK_NO_DETECT_OFF
					objOptionParam.SetNoiseDetect(MfErrorSelect.MF_ERROR_SELECT_NODETECT)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_NO_DETECT_ON
					objOptionParam.SetNoiseDetect(MfErrorSelect.MF_ERROR_SELECT_DETECT)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.bCheck_NO_Cancel
				Case ConstComVal.VAL_CONFIGDLG_CHECK_NO_CANCEL_OFF
					objOptionParam.SetNoiseCancel(MfCancel.MF_CANCEL_DISABLE)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_NO_CANCEL_ON
					objOptionParam.SetNoiseCancel(MfCancel.MF_CANCEL_ENABLE)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.nCombo_NO_EjectPocket
				Case ConstComVal.VAL_CONFIGDLG_COMBO_NO_EP_MAINPOCKET
					objOptionParam.SetNoiseEject(MfEject.MF_EJECT_MAIN_POCKET)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_NO_EP_SUBPOCKET
					objOptionParam.SetNoiseEject(MfEject.MF_EJECT_SUB_POCKET)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			' Double Feed
			Select Case objConfigData.bCheck_DF_Detect
				Case ConstComVal.VAL_CONFIGDLG_CHECK_DF_DETECT_OFF
					objOptionParam.SetDoubleFeedDetect(MfErrorSelect.MF_ERROR_SELECT_NODETECT)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_DF_DETECT_ON
					objOptionParam.SetDoubleFeedDetect(MfErrorSelect.MF_ERROR_SELECT_DETECT)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.bCheck_DF_Cancel
				Case ConstComVal.VAL_CONFIGDLG_CHECK_DF_CANCEL_OFF
					objOptionParam.SetDoubleFeedCancel(MfCancel.MF_CANCEL_DISABLE)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_DF_CANCEL_ON
					objOptionParam.SetDoubleFeedCancel(MfCancel.MF_CANCEL_ENABLE)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.nCombo_DF_EjectPocket
				Case ConstComVal.VAL_CONFIGDLG_COMBO_DF_EP_MAINPOCKET
					objOptionParam.SetDoubleFeedEject(MfEject.MF_EJECT_MAIN_POCKET)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_DF_EP_SUBPOCKET
					objOptionParam.SetDoubleFeedEject(MfEject.MF_EJECT_SUB_POCKET)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			' No Data
			Select Case objConfigData.bCheck_ND_Detect
				Case ConstComVal.VAL_CONFIGDLG_CHECK_ND_DETECT_OFF
					objOptionParam.SetNodataDetect(MfErrorSelect.MF_ERROR_SELECT_NODETECT)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_ND_DETECT_ON
					objOptionParam.SetNodataDetect(MfErrorSelect.MF_ERROR_SELECT_DETECT)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.bCheck_ND_Cancel
				Case ConstComVal.VAL_CONFIGDLG_CHECK_ND_CANCEL_OFF
					objOptionParam.SetNodataCancel(MfCancel.MF_CANCEL_DISABLE)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_ND_CANCEL_ON
					objOptionParam.SetNodataCancel(MfCancel.MF_CANCEL_ENABLE)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.nCombo_ND_EjectPocket
				Case ConstComVal.VAL_CONFIGDLG_COMBO_ND_EP_MAINPOCKET
					objOptionParam.SetNodataEject(MfEject.MF_EJECT_MAIN_POCKET)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_ND_EP_SUBPOCKET
					objOptionParam.SetNodataEject(MfEject.MF_EJECT_SUB_POCKET)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			' Bad Data
			Select Case objConfigData.bCheck_BD_Detect
				Case ConstComVal.VAL_CONFIGDLG_CHECK_BD_DETECT_OFF
					objOptionParam.SetBaddataDetect(MfErrorSelect.MF_ERROR_SELECT_NODETECT)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_BD_DETECT_ON
					objOptionParam.SetBaddataDetect(MfErrorSelect.MF_ERROR_SELECT_DETECT)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.bCheck_BD_Cancel
				Case ConstComVal.VAL_CONFIGDLG_CHECK_BD_CANCEL_OFF
					objOptionParam.SetBaddataCancel(MfCancel.MF_CANCEL_DISABLE)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_CHECK_BD_CANCEL_ON
					objOptionParam.SetBaddataCancel(MfCancel.MF_CANCEL_ENABLE)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objConfigData.nCombo_BD_EjectPocket
				Case ConstComVal.VAL_CONFIGDLG_COMBO_BD_EP_MAINPOCKET
					objOptionParam.SetBaddataEject(MfEject.MF_EJECT_MAIN_POCKET)
					Exit Select
				Case ConstComVal.VAL_CONFIGDLG_COMBO_BD_EP_SUBPOCKET
					objOptionParam.SetBaddataEject(MfEject.MF_EJECT_SUB_POCKET)
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select
		End Sub

		Private Sub ConvertBarcodeParamToConfigData(objBarcodeParam As CBarcodeParam, ByRef objConfigData As StructByStep)
			If objBarcodeParam Is Nothing OrElse objConfigData Is Nothing Then
				Debug.Assert(False)
				Return
			End If

			If (objBarcodeParam.GetBarcodeTypeMask() And MfBarcodeSymbol.MF_BARCODE_SYMBOL_CODABAR) = MfBarcodeSymbol.MF_BARCODE_SYMBOL_CODABAR Then
				objConfigData.bCheck_BT_SymbolCodabar = True
			Else
				objConfigData.bCheck_BT_SymbolCodabar = False
			End If

			If (objBarcodeParam.GetBarcodeTypeMask() And MfBarcodeSymbol.MF_BARCODE_SYMBOL_CODE128) = MfBarcodeSymbol.MF_BARCODE_SYMBOL_CODE128 Then
				objConfigData.bCheck_BT_SymbolCode128 = True
			Else
				objConfigData.bCheck_BT_SymbolCode128 = False
			End If

			If (objBarcodeParam.GetBarcodeTypeMask() And MfBarcodeSymbol.MF_BARCODE_SYMBOL_CODE39) = MfBarcodeSymbol.MF_BARCODE_SYMBOL_CODE39 Then
				objConfigData.bCheck_BT_SymbolCode39 = True
			Else
				objConfigData.bCheck_BT_SymbolCode39 = False
			End If

			If (objBarcodeParam.GetBarcodeTypeMask() And MfBarcodeSymbol.MF_BARCODE_SYMBOL_ITF) = MfBarcodeSymbol.MF_BARCODE_SYMBOL_ITF Then
				objConfigData.bCheck_BT_SymbolITF = True
			Else
				objConfigData.bCheck_BT_SymbolITF = False
			End If

			If (objBarcodeParam.GetBarcodeTypeMask() And MfBarcodeSymbol.MF_BARCODE_SYMBOL_EAN_JAN) = MfBarcodeSymbol.MF_BARCODE_SYMBOL_EAN_JAN Then
				objConfigData.bCheck_BT_SymbolEAN = True
			Else
				objConfigData.bCheck_BT_SymbolEAN = False
			End If

			If (objBarcodeParam.GetBarcodeTypeMask() And MfBarcodeSymbol.MF_BARCODE_SYMBOL_UPC_A) = MfBarcodeSymbol.MF_BARCODE_SYMBOL_UPC_A Then
				objConfigData.bCheck_BT_SymbolUPCA = True
			Else
				objConfigData.bCheck_BT_SymbolUPCA = False
			End If

			If (objBarcodeParam.GetBarcodeTypeMask() And MfBarcodeSymbol.MF_BARCODE_SYMBOL_UPC_E) = MfBarcodeSymbol.MF_BARCODE_SYMBOL_UPC_E Then
				objConfigData.bCheck_BT_SymbolUPCE = True
			Else
				objConfigData.bCheck_BT_SymbolUPCE = False
			End If

			Select Case objBarcodeParam.GetBarcodeDetect()
				Case MfErrorSelect.MF_ERROR_SELECT_NODETECT
					objConfigData.bCheck_BA_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_BA_DETECT_OFF
					Exit Select
				Case MfErrorSelect.MF_ERROR_SELECT_DETECT
					objConfigData.bCheck_BA_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_BA_DETECT_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objBarcodeParam.GetBarcodeCancel()
				Case MfCancel.MF_CANCEL_DISABLE
					objConfigData.bCheck_BA_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_BA_CANCEL_OFF
					Exit Select
				Case MfCancel.MF_CANCEL_ENABLE
					objConfigData.bCheck_BA_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_BA_CANCEL_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objBarcodeParam.GetBarcodeEject()
				Case MfEject.MF_EJECT_MAIN_POCKET
					objConfigData.nCombo_BA_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_BA_EP_MAINPOCKET
					Exit Select
				Case MfEject.MF_EJECT_SUB_POCKET
					objConfigData.nCombo_BA_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_BA_EP_SUBPOCKET
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select
		End Sub

		Private Sub ConvertOptionParamToConfigData(objOptionParam As COptionParam, ByRef objConfigData As StructByStep)
			If objOptionParam Is Nothing OrElse objConfigData Is Nothing Then
				Debug.Assert(False)
				Return
			End If

			' PaperMisInsertion
			Select Case objOptionParam.GetPaperMisInsertionDetect()
				Case MfErrorSelect.MF_ERROR_SELECT_NODETECT
					objConfigData.bCheck_PI_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_PI_DETECT_OFF
					Exit Select
				Case MfErrorSelect.MF_ERROR_SELECT_DETECT
					objConfigData.bCheck_PI_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_PI_DETECT_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetPaperMisInsertionCancel()
				Case MfCancel.MF_CANCEL_DISABLE
					objConfigData.bCheck_PI_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_PI_CANCEL_OFF
					Exit Select
				Case MfCancel.MF_CANCEL_ENABLE
					objConfigData.bCheck_PI_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_PI_CANCEL_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetPaperMisInsertionEject()
				Case MfEject.MF_EJECT_MAIN_POCKET
					objConfigData.nCombo_PI_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_PI_EP_MAINPOCKET
					Exit Select
				Case MfEject.MF_EJECT_SUB_POCKET
					objConfigData.nCombo_PI_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_PI_EP_SUBPOCKET
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			' Noise
			Select Case objOptionParam.GetNoiseDetect()
				Case MfErrorSelect.MF_ERROR_SELECT_NODETECT
					objConfigData.bCheck_NO_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_NO_DETECT_OFF
					Exit Select
				Case MfErrorSelect.MF_ERROR_SELECT_DETECT
					objConfigData.bCheck_NO_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_NO_DETECT_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetNoiseCancel()
				Case MfCancel.MF_CANCEL_DISABLE
					objConfigData.bCheck_NO_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_NO_CANCEL_OFF
					Exit Select
				Case MfCancel.MF_CANCEL_ENABLE
					objConfigData.bCheck_NO_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_NO_CANCEL_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetNoiseEject()
				Case MfEject.MF_EJECT_MAIN_POCKET
					objConfigData.nCombo_NO_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_NO_EP_MAINPOCKET
					Exit Select
				Case MfEject.MF_EJECT_SUB_POCKET
					objConfigData.nCombo_NO_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_NO_EP_SUBPOCKET
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			' Double Feed
			Select Case objOptionParam.GetDoubleFeedDetect()
				Case MfErrorSelect.MF_ERROR_SELECT_NODETECT
					objConfigData.bCheck_DF_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_DF_DETECT_OFF
					Exit Select
				Case MfErrorSelect.MF_ERROR_SELECT_DETECT
					objConfigData.bCheck_DF_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_DF_DETECT_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetDoubleFeedCancel()
				Case MfCancel.MF_CANCEL_DISABLE
					objConfigData.bCheck_DF_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_DF_CANCEL_OFF
					Exit Select
				Case MfCancel.MF_CANCEL_ENABLE
					objConfigData.bCheck_DF_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_DF_CANCEL_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetDoubleFeedEject()
				Case MfEject.MF_EJECT_MAIN_POCKET
					objConfigData.nCombo_DF_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_DF_EP_MAINPOCKET
					Exit Select
				Case MfEject.MF_EJECT_SUB_POCKET
					objConfigData.nCombo_DF_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_DF_EP_SUBPOCKET
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			' No Data
			Select Case objOptionParam.GetNodataDetect()
				Case MfErrorSelect.MF_ERROR_SELECT_NODETECT
					objConfigData.bCheck_ND_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_ND_DETECT_OFF
					Exit Select
				Case MfErrorSelect.MF_ERROR_SELECT_DETECT
					objConfigData.bCheck_ND_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_ND_DETECT_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetNodataCancel()
				Case MfCancel.MF_CANCEL_DISABLE
					objConfigData.bCheck_ND_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_ND_CANCEL_OFF
					Exit Select
				Case MfCancel.MF_CANCEL_ENABLE
					objConfigData.bCheck_ND_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_ND_CANCEL_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetNodataEject()
				Case MfEject.MF_EJECT_MAIN_POCKET
					objConfigData.nCombo_ND_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_ND_EP_MAINPOCKET
					Exit Select
				Case MfEject.MF_EJECT_SUB_POCKET
					objConfigData.nCombo_ND_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_ND_EP_SUBPOCKET
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			' Bad Data
			Select Case objOptionParam.GetBaddataDetect()
				Case MfErrorSelect.MF_ERROR_SELECT_NODETECT
					objConfigData.bCheck_BD_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_BD_DETECT_OFF
					Exit Select
				Case MfErrorSelect.MF_ERROR_SELECT_DETECT
					objConfigData.bCheck_BD_Detect = ConstComVal.VAL_CONFIGDLG_CHECK_BD_DETECT_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetBaddataCancel()
				Case MfCancel.MF_CANCEL_DISABLE
					objConfigData.bCheck_BD_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_BD_CANCEL_OFF
					Exit Select
				Case MfCancel.MF_CANCEL_ENABLE
					objConfigData.bCheck_BD_Cancel = ConstComVal.VAL_CONFIGDLG_CHECK_BD_CANCEL_ON
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select

			Select Case objOptionParam.GetBaddataEject()
				Case MfEject.MF_EJECT_MAIN_POCKET
					objConfigData.nCombo_BD_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_BD_EP_MAINPOCKET
					Exit Select
				Case MfEject.MF_EJECT_SUB_POCKET
					objConfigData.nCombo_BD_EjectPocket = ConstComVal.VAL_CONFIGDLG_COMBO_BD_EP_SUBPOCKET
					Exit Select
				Case Else
					Debug.Assert(False)
					Exit Select
			End Select
		End Sub
	End Class
End Namespace
